﻿B4J=true
Group=Default Group
ModulesStructureVersion=1
Type=Class
Version=10
@EndOfDesignText@
Sub Class_Globals

	Type wmHtmlCode(id As Int, symbol As String, htmlCode As String, CSScode As String, unicode As String, entity As String, name As String, group As String)
	Private listHtmlCodes As List ' Contains variables of type wmHtmlCode

	' Maps to fetch a code by its various properties.
	' An in-memory SQLIte db was considered, but that would require the SQLite libraries to be added.
	' Key: CSScode, entity, ...; Value: the index of the data in listHtmlCodes
	Private mapCSScode As Map
	Private mapEntity As Map
	Private mapHtmlCode As Map
	Private mapName As Map
	Private mapSymbol As Map
	Private mapUnicode As Map

	' Used internally for method DecodeHtml
	Private xmlEntities As Map
	Private matcherPattern As String

End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize

	listHtmlCodes.Initialize
	mapCSScode.Initialize
	mapEntity.Initialize
	mapHtmlCode.Initialize
	mapName.Initialize
	mapSymbol.Initialize
	mapUnicode.Initialize

	xmlEntities.Initialize
	matcherPattern = "&(#\d+"

	AddCode("", "", "", "", "", "", "") ' Default entry for 'not found'

	' Data obtained from https://symbl.cc/en/html-entities/
	' This was broken up into 2 methods as otherwise compiling in Debug mode would fail.
	AddCodes1
	AddCodes2

	' Data added from elsewhere
	AddCode("Ì", "&#204;", "\00CC", "U+00CC", "&Igrave;", "Latin Capital Letter I with Grave", "Latin Letters")
	AddCode("Í", "&#205;", "\00CD", "U+00CD", "&Iacute;", "Latin Capital Letter I with Acute", "Latin Letters")
	AddCode("Î", "&#206;", "\00CE", "U+00CE", "&Icirc;", "Latin Capital Letter I with Circumflex", "Latin Letters")
	AddCode("Ï", "&#207;", "\00CF", "U+00CF", "&Iuml;", "Latin Capital Letter I with Diaeresis", "Latin Letters")
	AddCode("€", "&#8364;", "\20AC", "U+20AC", "&euro;", "Euro", "Currency")

	matcherPattern = matcherPattern & ");"

End Sub

Private Sub AddCodes1

	AddCode("$", "&#36;", "\0024", "U+0024", "&dollar;", "Dollar Sign", "Currency")
	AddCode("¢", "&#162;", "\00A2", "U+00A2", "&cent;", "Cent Sign", "Currency")
	AddCode("£", "&#163;", "\00A3", "U+00A3", "&pound;", "Pound Sign", "Currency")
	AddCode("¤", "&#164;", "\00A4", "U+00A4", "&curren;", "Currency Sign", "Currency")
	AddCode("¥", "&#165;", "\00A5", "U+00A5", "&yen;", "Yen Sign", "Currency")
	AddCode("©", "&#169;", "\00A9", "U+00A9", "&copy;", "Copyright", "Miscellaneous Symbols")
	AddCode("®", "&#174;", "\00AE", "U+00AE", "&reg;", "Registered", "Miscellaneous Symbols")
	AddCode("™", "&#8482;", "\2122", "U+2122", "&trade;", "Trade Mark", "Miscellaneous Symbols")
	AddCode("@", "&#64;", "\0040", "U+0040", "&commat;", "Commercial At", "Miscellaneous Symbols")
	AddCode("ℂ", "&#8450;", "\2102", "U+2102", "&Copf;", "Double-Struck Capital C", "Miscellaneous Symbols")
	AddCode("℅", "&#8453;", "\2105", "U+2105", "&incare;", "Care Of", "Miscellaneous Symbols")
	AddCode("ℊ", "&#8458;", "\210A", "U+210A", "&gscr;", "Script Small G", "Miscellaneous Symbols")
	AddCode("ℋ", "&#8459;", "\210B", "U+210B", "&hamilt;", "Script Capital H", "Miscellaneous Symbols")
	AddCode("ℌ", "&#8460;", "\210C", "U+210C", "&Hfr;", "Black-Letter Capital H", "Miscellaneous Symbols")
	AddCode("ℍ", "&#8461;", "\210D", "U+210D", "&Hopf;", "Double-Struck Capital H", "Miscellaneous Symbols")
	AddCode("ℎ", "&#8462;", "\210E", "U+210E", "&planckh;", "Planck Constant", "Miscellaneous Symbols")
	AddCode("ℏ", "&#8463;", "\210F", "U+210F", "&planck;", "Planck Constant Over Two Pi", "Miscellaneous Symbols")
	AddCode("ℐ", "&#8464;", "\2110", "U+2110", "&Iscr;", "Script Capital I", "Miscellaneous Symbols")
	AddCode("ℑ", "&#8465;", "\2111", "U+2111", "&image;", "Black-Letter Capital I", "Miscellaneous Symbols")
	AddCode("ℒ", "&#8466;", "\2112", "U+2112", "&Lscr;", "Script Capital L", "Miscellaneous Symbols")
	AddCode("ℓ", "&#8467;", "\2113", "U+2113", "&ell;", "Script Small L", "Miscellaneous Symbols")
	AddCode("ℕ", "&#8469;", "\2115", "U+2115", "&Nopf;", "Double-Struck Capital N", "Miscellaneous Symbols")
	AddCode("№", "&#8470;", "\2116", "U+2116", "&numero;", "Numero Sign", "Miscellaneous Symbols")
	AddCode("℗", "&#8471;", "\2117", "U+2117", "&copysr;", "Sound Recording Copyright", "Miscellaneous Symbols")
	AddCode("℘", "&#8472;", "\2118", "U+2118", "&weierp;", "Script Capital P", "Miscellaneous Symbols")
	AddCode("ℙ", "&#8473;", "\2119", "U+2119", "&Popf;", "Double-Struck Capital P", "Miscellaneous Symbols")
	AddCode("ℚ", "&#8474;", "\211A", "U+211A", "&Qopf;", "Double-Struck Capital Q", "Miscellaneous Symbols")
	AddCode("ℛ", "&#8475;", "\211B", "U+211B", "&Rscr;", "Script Capital R", "Miscellaneous Symbols")
	AddCode("ℜ", "&#8476;", "\211C", "U+211C", "&real;", "Black-Letter Capital R", "Miscellaneous Symbols")
	AddCode("ℝ", "&#8477;", "\211D", "U+211D", "&Ropf;", "Double-Struck Capital R", "Miscellaneous Symbols")
	AddCode("℞", "&#8478;", "\211E", "U+211E", "&rx;", "Prescription Take", "Miscellaneous Symbols")
	AddCode("ℤ", "&#8484;", "\2124", "U+2124", "&Zopf;", "Double-Struck Capital Z", "Miscellaneous Symbols")
	AddCode("℧", "&#8487;", "\2127", "U+2127", "&mho;", "Inverted Ohm Sign", "Miscellaneous Symbols")
	AddCode("ℨ", "&#8488;", "\2128", "U+2128", "&Zfr;", "Black-Letter Capital Z", "Miscellaneous Symbols")
	AddCode("℩", "&#8489;", "\2129", "U+2129", "&iiota;", "Turned Greek Small Letter Iota", "Miscellaneous Symbols")
	AddCode("ℬ", "&#8492;", "\212C", "U+212C", "&bernou;", "Script Capital B", "Miscellaneous Symbols")
	AddCode("ℭ", "&#8493;", "\212D", "U+212D", "&Cfr;", "Black-Letter Capital C", "Miscellaneous Symbols")
	AddCode("ℯ", "&#8495;", "\212F", "U+212F", "&escr;", "Script Small E", "Miscellaneous Symbols")
	AddCode("ℰ", "&#8496;", "\2130", "U+2130", "&Escr;", "Script Capital E", "Miscellaneous Symbols")
	AddCode("ℱ", "&#8497;", "\2131", "U+2131", "&Fscr;", "Script Capital F", "Miscellaneous Symbols")
	AddCode("ℳ", "&#8499;", "\2133", "U+2133", "&Mscr;", "Script Capital M", "Miscellaneous Symbols")
	AddCode("ℴ", "&#8500;", "\2134", "U+2134", "&oscr;", "Script Small O", "Miscellaneous Symbols")
	AddCode("ℵ", "&#8501;", "\2135", "U+2135", "&alefsym;", "Alef Symbol", "Miscellaneous Symbols")
	AddCode("ℶ", "&#8502;", "\2136", "U+2136", "&beth;", "Bet Symbol", "Miscellaneous Symbols")
	AddCode("ℷ", "&#8503;", "\2137", "U+2137", "&gimel;", "Gimel Symbol", "Miscellaneous Symbols")
	AddCode("ℸ", "&#8504;", "\2138", "U+2138", "&daleth;", "Dalet Symbol", "Miscellaneous Symbols")
	AddCode("ⅅ", "&#8517;", "\2145", "U+2145", "&DD;", "Double-Struck Italic Capital D", "Miscellaneous Symbols")
	AddCode("ⅆ", "&#8518;", "\2146", "U+2146", "&dd;", "Double-Struck Italic Small D", "Miscellaneous Symbols")
	AddCode("ⅇ", "&#8519;", "\2147", "U+2147", "&ee;", "Double-Struck Italic Small E", "Miscellaneous Symbols")
	AddCode("ⅈ", "&#8520;", "\2148", "U+2148", "&ii;", "Double-Struck Italic Small I", "Miscellaneous Symbols")
	AddCode("★", "&#9733;", "\2605", "U+2605", "&starf;", "Black Star", "Miscellaneous Symbols")
	AddCode("☆", "&#9734;", "\2606", "U+2606", "&star;", "White Star", "Miscellaneous Symbols")
	AddCode(" ", "&#9742;", "\260E", "U+260E", "&phone;", "Telephone", "Miscellaneous Symbols")
	AddCode("♀", "&#9792;", "\2640", "U+2640", "&female;", "Female Sign", "Miscellaneous Symbols")
	AddCode("♂", "&#9794;", "\2642", "U+2642", "&male;", "Male Sign", "Miscellaneous Symbols")
	AddCode(" ", "&#9824;", "\2660", "U+2660", "&spades;", "Spade Suit", "Miscellaneous Symbols")
	AddCode(" ", "&#9827;", "\2663", "U+2663", "&clubs;", "Club Suit", "Miscellaneous Symbols")
	AddCode(" ", "&#9829;", "\2665", "U+2665", "&hearts;", "Heart Suit", "Miscellaneous Symbols")
	AddCode(" ", "&#9830;", "\2666", "U+2666", "&diams;", "Diamond Suit", "Miscellaneous Symbols")
	AddCode("◊", "&#9674;", "\25CA", "U+25CA", "&loz;", "Lozenge", "Miscellaneous Symbols")
	AddCode("♪", "&#9834;", "\266A", "U+266A", "&sung;", "Eighth Note", "Miscellaneous Symbols")
	AddCode("♭", "&#9837;", "\266D", "U+266D", "&flat;", "Music Flat Sign", "Miscellaneous Symbols")
	AddCode("♮", "&#9838;", "\266E", "U+266E", "&natural;", "Music Natural Sign", "Miscellaneous Symbols")
	AddCode("♯", "&#9839;", "\266F", "U+266F", "&sharp;", "Music Sharp Sign", "Miscellaneous Symbols")
	AddCode("✓", "&#10003;", "\2713", "U+2713", "&check;", "Check Mark", "Miscellaneous Symbols")
	AddCode("✗", "&#10007;", "\2717", "U+2717", "&cross;", "Ballot X", "Miscellaneous Symbols")
	AddCode("✠", "&#10016;", "\2720", "U+2720", "&malt;", "Maltese Cross", "Miscellaneous Symbols")
	AddCode("✶", "&#10038;", "\2736", "U+2736", "&sext;", "Six Pointed Black Star", "Miscellaneous Symbols")
	AddCode("❘", "&#10072;", "\2758", "U+2758", "&VerticalSeparator;", "Light Vertical Bar", "Miscellaneous Symbols")
	AddCode("❲", "&#10098;", "\2772", "U+2772", "&lbbrk;", "Light Left Tortoise Shell Bracket Ornament", "Miscellaneous Symbols")
	AddCode("❳", "&#10099;", "\2773", "U+2773", "&rbbrk;", "Light Right Tortoise Shell Bracket Ornament", "Miscellaneous Symbols")
	AddCode("!", "&#33;", "\0021", "U+0021", "&excl;", "Exclamation Mark", "Punctuation Symbols")
	AddCode("#", "&#35;", "\0023", "U+0023", "&num;", "Number Sign", "Punctuation Symbols")
	AddCode("%", "&#37;", "\0025", "U+0025", "&percnt;", "Percent Sign", "Punctuation Symbols")
	AddCode("&", "&#38;", "\0026", "U+0026", "&amp;", "Ampersand", "Punctuation Symbols")
	AddCode("(", "&#40;", "\0028", "U+0028", "&lpar;", "Left Parenthesis", "Punctuation Symbols")
	AddCode(")", "&#41;", "\0029", "U+0029", "&rpar;", "Right Parenthesis", "Punctuation Symbols")
	AddCode("*", "&#42;", "\002A", "U+002A", "&ast;", "Asterisk", "Punctuation Symbols")
	AddCode(",", "&#44;", "\002C", "U+002C", "&comma;", "Comma", "Punctuation Symbols")
	AddCode(".", "&#46;", "\002E", "U+002E", "&period;", "Full Stop", "Punctuation Symbols")
	AddCode("/", "&#47;", "\002F", "U+002F", "&sol;", "Solidus", "Punctuation Symbols")
	AddCode(":", "&#58;", "\003A", "U+003A", "&colon;", "Colon", "Punctuation Symbols")
	AddCode(";", "&#59;", "\003B", "U+003B", "&semi;", "Semicolon", "Punctuation Symbols")
	AddCode("?", "&#63;", "\003F", "U+003F", "&quest;", "Question Mark", "Punctuation Symbols")
	AddCode("[", "&#91;", "\005B", "U+005B", "&lbrack;", "Left Square Bracket", "Punctuation Symbols")
	AddCode("\", "&#92;", "\005C", "U+005C", "&bsol;", "Reverse Solidus", "Punctuation Symbols")
	AddCode("]", "&#93;", "\005D", "U+005D", "&rbrack;", "Right Square Bracket", "Punctuation Symbols")
	AddCode("^", "&#94;", "\005E", "U+005E", "&Hat;", "Circumflex Accent", "Punctuation Symbols")
	AddCode("_", "&#95;", "\005F", "U+005F", "&lowbar;", "Low Line", "Punctuation Symbols")
	AddCode("`", "&#96;", "\0060", "U+0060", "&grave;", "Grave Accent", "Punctuation Symbols")
	AddCode("{", "&#123;", "\007B", "U+007B", "&lbrace;", "Left Curly Bracket", "Punctuation Symbols")
	AddCode("|", "&#124;", "\007C", "U+007C", "&vert;", "Vertical Line", "Punctuation Symbols")
	AddCode("}", "&#125;", "\007D", "U+007D", "&rbrace;", "Right Curly Bracket", "Punctuation Symbols")
	AddCode("~", "&#126;", "\007E", "U+007E", "&tilde;", "Tilde", "Punctuation Symbols")
	AddCode("ˆ", "&#710;", "\02C6", "U+02C6", "&circ;", "Modifier Letter Circumflex Accent", "Punctuation Symbols")
	AddCode(" ", "&#160;", "\00A0", "U+00A0", "&nbsp;", "No-Break Space", "Punctuation Symbols")
	AddCode(" ", "&#8194;", "\2002", "U+2002", "&ensp;", "En Space", "Punctuation Symbols")
	AddCode(" ", "&#8195;", "\2003", "U+2003", "&emsp;", "Em Space", "Punctuation Symbols")
	AddCode(" ", "&#8201;", "\2009", "U+2009", "&thinsp;", "Thin Space", "Punctuation Symbols")
	AddCode("", "&#8204;", "\200C", "U+200C", "&zwnj;", "Zero Width Non-Joiner", "Punctuation Symbols")
	AddCode("", "&#8205;", "\200D", "U+200D", "&zwj;", "Zero Width Joiner", "Punctuation Symbols")
	AddCode("", "&#8206;", "\200E", "U+200E", "&lrm;", "Left-To-Right Mark", "Punctuation Symbols")
	AddCode("", "&#8207;", "\200F", "U+200F", "&rlm;", "Right-To-Left Mark", "Punctuation Symbols")
	AddCode("¡", "&#161;", "\00A1", "U+00A1", "&iexcl;", "Inverted Exclamation Mark", "Punctuation Symbols")
	AddCode("¦", "&#166;", "\00A6", "U+00A6", "&brvbar;", "Broken Bar", "Punctuation Symbols")
	AddCode("§", "&#167;", "\00A7", "U+00A7", "&sect;", "Section Sign", "Punctuation Symbols")
	AddCode("¨", "&#168;", "\00A8", "U+00A8", "&uml;", "Diaeresis", "Punctuation Symbols")
	AddCode("ª", "&#170;", "\00AA", "U+00AA", "&ordf;", "Feminine Ordinal Indicator", "Punctuation Symbols")
	AddCode("¬", "&#172;", "\00AC", "U+00AC", "&not;", "Not Sign", "Punctuation Symbols")
	AddCode("­", "&#173;", "\00AD", "U+00AD", "&shy;", "Soft Hyphen", "Punctuation Symbols")
	AddCode("¯", "&#175;", "\00AF", "U+00AF", "&macr;", "Macron", "Punctuation Symbols")
	AddCode("²", "&#178;", "\00B2", "U+00B2", "&sup2;", "Superscript Two", "Punctuation Symbols")
	AddCode("³", "&#179;", "\00B3", "U+00B3", "&sup3;", "Superscript Three", "Punctuation Symbols")
	AddCode("´", "&#180;", "\00B4", "U+00B4", "&acute;", "Acute Accent", "Punctuation Symbols")
	AddCode("µ", "&#181;", "\00B5", "U+00B5", "&micro;", "Micro Sign", "Punctuation Symbols")
	AddCode("¶", "&#182;", "\00B6", "U+00B6", "&para;", "Pilcrow Sign", "Punctuation Symbols")
	AddCode("·", "&#183;", "\00B7", "U+00B7", "&middot;", "Middle Dot", "Punctuation Symbols")
	AddCode("¸", "&#184;", "\00B8", "U+00B8", "&cedil;", "Cedilla", "Punctuation Symbols")
	AddCode("¹", "&#185;", "\00B9", "U+00B9", "&sup1;", "Superscript One", "Punctuation Symbols")
	AddCode("º", "&#186;", "\00BA", "U+00BA", "&ordm;", "Masculine Ordinal Indicator", "Punctuation Symbols")
	AddCode("¿", "&#191;", "\00BF", "U+00BF", "&iquest;", "Inverted Question Mark", "Punctuation Symbols")
	AddCode("‐", "&#8208;", "\2010", "U+2010", "&hyphen;", "Hyphen", "Punctuation Symbols")
	AddCode("–", "&#8211;", "\2013", "U+2013", "&ndash;", "En Dash", "Punctuation Symbols")
	AddCode("—", "&#8212;", "\2014", "U+2014", "&mdash;", "Em Dash", "Punctuation Symbols")
	AddCode("―", "&#8213;", "\2015", "U+2015", "&horbar;", "Horizontal Bar", "Punctuation Symbols")
	AddCode("‖", "&#8214;", "\2016", "U+2016", "&Vert;", "Double Vertical Line", "Punctuation Symbols")
	AddCode("†", "&#8224;", "\2020", "U+2020", "&dagger;", "Dagger", "Punctuation Symbols")
	AddCode("‡", "&#8225;", "\2021", "U+2021", "&Dagger;", "Double Dagger", "Punctuation Symbols")
	AddCode("•", "&#8226;", "\2022", "U+2022", "&bull;", "Bullet", "Punctuation Symbols")
	AddCode("‥", "&#8229;", "\2025", "U+2025", "&nldr;", "Two Dot Leader", "Punctuation Symbols")
	AddCode("…", "&#8230;", "\2026", "U+2026", "&hellip;", "Horizontal Ellipsis", "Punctuation Symbols")
	AddCode("‰", "&#8240;", "\2030", "U+2030", "&;", "Per Mille Sign", "Punctuation Symbols")
	AddCode("‱", "&#8241;", "\2031", "U+2031", "&pertenk;", "Per Ten Thousand Sign", "Punctuation Symbols")
	AddCode("′", "&#8242;", "\2032", "U+2032", "&prime;", "Prime", "Punctuation Symbols")
	AddCode("″", "&#8243;", "\2033", "U+2033", "&Prime;", "Double Prime", "Punctuation Symbols")
	AddCode("‴", "&#8244;", "\2034", "U+2034", "&tprime;", "Triple Prime", "Punctuation Symbols")
	AddCode("‵", "&#8245;", "\2035", "U+2035", "&bprime;", "Reversed Prime", "Punctuation Symbols")
	AddCode("‾", "&#8254;", "\203E", "U+203E", "&oline;", "Overline", "Punctuation Symbols")
	AddCode("⁁", "&#8257;", "\2041", "U+2041", "&caret;", "Caret Insertion Point", "Punctuation Symbols")
	AddCode("⁃", "&#8259;", "\2043", "U+2043", "&hybull;", "Hyphen Bullet", "Punctuation Symbols")
	AddCode("⁄", "&#8260;", "\2044", "U+2044", "&frasl;", "Fraction Slash", "Punctuation Symbols")
	AddCode("⁏", "&#8271;", "\204F", "U+204F", "&bsemi;", "Reversed Semicolon", "Punctuation Symbols")
	AddCode("⁗", "&#8279;", "\2057", "U+2057", "&qprime;", "Quadruple Prime", "Punctuation Symbols")
	AddCode(QUOTE, "&#34;", "\0022", "U+0022", "&quot;", "Quotation Mark", "Quotation Marks")
	AddCode("'", "&#39;", "\0027", "U+0027", "&apos;", "Apostrophe", "Quotation Marks")
	AddCode("«", "&#171;", "\00AB", "U+00AB", "&laquo;", "Left-Pointing Double Angle Quotation Mark", "Quotation Marks")
	AddCode("»", "&#187;", "\00BB", "U+00BB", "&raquo;", "Right-Pointing Double Angle Quotation Mark", "Quotation Marks")
	AddCode("‘", "&#8216;", "\2018", "U+2018", "&lsquo;", "Left Single Quotation Mark", "Quotation Marks")
	AddCode("’", "&#8217;", "\2019", "U+2019", "&rsquo;", "Right Single Quotation Mark", "Quotation Marks")
	AddCode("‚", "&#8218;", "\201A", "U+201A", "&sbquo;", "Single Low-9 Quotation Mark", "Quotation Marks")
	AddCode("“", "&#8220;", "\201C", "U+201C", "&ldquo;", "Left Double Quotation Mark", "Quotation Marks")
	AddCode("”", "&#8221;", "\201D", "U+201D", "&rdquo;", "Right Double Quotation Mark", "Quotation Marks")
	AddCode("„", "&#8222;", "\201E", "U+201E", "&bdquo;", "Double Low-9 Quotation Mark", "Quotation Marks")
	AddCode("‹", "&#8249;", "\2039", "U+2039", "&lsaquo;", "Single Left-Pointing Angle Quotation Mark", "Quotation Marks")
	AddCode("›", "&#8250;", "\203A", "U+203A", "&rsaquo;", "Single Right-Pointing Angle Quotation Mark", "Quotation Marks")
	AddCode("¼", "&#188;", "\00BC", "U+00BC", "&frac14;", "Vulgar Fraction One Quarter", "Fractions")
	AddCode("½", "&#189;", "\00BD", "U+00BD", "&frac12;", "Vulgar Fraction One Half", "Fractions")
	AddCode("¾", "&#190;", "\00BE", "U+00BE", "&frac34;", "Vulgar Fraction Three Quarters", "Fractions")
	AddCode("⅓", "&#8531;", "\2153", "U+2153", "&frac13;", "Vulgar Fraction One Third", "Fractions")
	AddCode("⅔", "&#8532;", "\2154", "U+2154", "&frac23;", "Vulgar Fraction Two Thirds", "Fractions")
	AddCode("⅕", "&#8533;", "\2155", "U+2155", "&frac15;", "Vulgar Fraction One Fifth", "Fractions")
	AddCode("⅖", "&#8534;", "\2156", "U+2156", "&frac25;", "Vulgar Fraction Two Fifths", "Fractions")
	AddCode("⅗", "&#8535;", "\2157", "U+2157", "&frac35;", "Vulgar Fraction Three Fifths", "Fractions")
	AddCode("⅘", "&#8536;", "\2158", "U+2158", "&frac45;", "Vulgar Fraction Four Fifths", "Fractions")
	AddCode("⅙", "&#8537;", "\2159", "U+2159", "&frac16;", "Vulgar Fraction One Sixth", "Fractions")
	AddCode("⅚", "&#8538;", "\215A", "U+215A", "&frac56;", "Vulgar Fraction Five Sixths", "Fractions")
	AddCode("⅛", "&#8539;", "\215B", "U+215B", "&frac18;", "Vulgar Fraction One Eighth", "Fractions")
	AddCode("⅜", "&#8540;", "\215C", "U+215C", "&frac38;", "Vulgar Fraction Three Eighths", "Fractions")
	AddCode("⅝", "&#8541;", "\215D", "U+215D", "&frac58;", "Vulgar Fraction Five Eighths", "Fractions")
	AddCode("⅞", "&#8542;", "\215E", "U+215E", "&frac78;", "Vulgar Fraction Seven Eighths", "Fractions")
	AddCode("+", "&#43;", "\002B", "U+002B", "&plus;", "Plus Sign", "Math Symbols")
	AddCode("−", "&#8722;", "\2212", "U+2212", "&minus;", "Minus Sign", "Math Symbols")
	AddCode("×", "&#215;", "\00D7", "U+00D7", "&times;", "Multiplication Sign", "Math Symbols")
	AddCode("÷", "&#247;", "\00F7", "U+00F7", "&divide;", "Division Sign", "Math Symbols")
	AddCode("=", "&#61;", "\003D", "U+003D", "&equals;", "Equals Sign", "Math Symbols")
	AddCode("≠", "&#8800;", "\2260", "U+2260", "&ne;", "Not Equal To", "Math Symbols")
	AddCode("±", "&#177;", "\00B1", "U+00B1", "&plusmn;", "Plus minus symbol", "Math Symbols")
	AddCode("¬", "&#172;", "\00AC", "U+00AC", "&not;", "Not Sign", "Math Symbols")
	AddCode("<", "&#60;", "\003C", "U+003C", "&lt;", "Less-Than Sign", "Math Symbols")
	AddCode(">", "&#62;", "\003E", "U+003E", "&gt;", "Greater-Than Sign", "Math Symbols")
	AddCode("°", "&#176;", "\00B0", "U+00B0", "&deg;", "Degree Sign", "Math Symbols")
	AddCode("¹", "&#185;", "\00B9", "U+00B9", "&sup1;", "Superscript One", "Math Symbols")
	AddCode("²", "&#178;", "\00B2", "U+00B2", "&sup2;", "Superscript Two", "Math Symbols")
	AddCode("³", "&#179;", "\00B3", "U+00B3", "&sup3;", "Superscript Three", "Math Symbols")
	AddCode("ƒ", "&#402;", "\0192", "U+0192", "&fnof;", "Latin Small Letter F with Hook", "Math Symbols")
	AddCode("%", "&#37;", "\0025", "U+0025", "&percnt;", "Percent Sign", "Math Symbols")
	AddCode("", "&#137;", "\0089", "U+0089", "&permil;", "Character Tabulation with Justification", "Math Symbols")
	AddCode("‱", "&#8241;", "\2031", "U+2031", "&pertenk;", "Per Ten Thousand Sign", "Math Symbols")
	AddCode("∀", "&#8704;", "\2200", "U+2200", "&forall;", "For All", "Math Symbols")
	AddCode("∁", "&#8705;", "\2201", "U+2201", "&comp;", "Complement", "Math Symbols")
	AddCode("∂", "&#8706;", "\2202", "U+2202", "&part;", "Partial Differential", "Math Symbols")
	AddCode("∃", "&#8707;", "\2203", "U+2203", "&exist;", "There Exists", "Math Symbols")
	AddCode("∄", "&#8708;", "\2204", "U+2204", "&nexist;", "There Does Not Exist", "Math Symbols")
	AddCode("∅", "&#8709;", "\2205", "U+2205", "&empty;", "Empty Set", "Math Symbols")
	AddCode("∇", "&#8711;", "\2207", "U+2207", "&nabla;", "Nabla", "Math Symbols")
	AddCode("∈", "&#8712;", "\2208", "U+2208", "&isin;", "Element Of", "Math Symbols")
	AddCode("∉", "&#8713;", "\2209", "U+2209", "&notin;", "Not an Element Of", "Math Symbols")
	AddCode("∋", "&#8715;", "\220B", "U+220B", "&ni;", "Contains As Member", "Math Symbols")
	AddCode("∌", "&#8716;", "\220C", "U+220C", "&notni;", "Does Not Contain As Member", "Math Symbols")
	AddCode("∏", "&#8719;", "\220F", "U+220F", "&prod;", "N-Ary Product", "Math Symbols")
	AddCode("∐", "&#8720;", "\2210", "U+2210", "&coprod;", "N-Ary Coproduct", "Math Symbols")
	AddCode("∑", "&#8721;", "\2211", "U+2211", "&sum;", "N-Ary Summation", "Math Symbols")
	AddCode("∓", "&#8723;", "\2213", "U+2213", "&mnplus;", "Minus-or-Plus Sign", "Math Symbols")
	AddCode("∔", "&#8724;", "\2214", "U+2214", "&plusdo;", "Dot Plus", "Math Symbols")
	AddCode("∖", "&#8726;", "\2216", "U+2216", "&setminus;", "Set Minus", "Math Symbols")
	AddCode("∗", "&#8727;", "\2217", "U+2217", "&lowast;", "Asterisk Operator", "Math Symbols")
	AddCode("∘", "&#8728;", "\2218", "U+2218", "&compfn;", "Ring Operator", "Math Symbols")
	AddCode("√", "&#8730;", "\221A", "U+221A", "&radic;", "Square Root", "Math Symbols")
	AddCode("∝", "&#8733;", "\221D", "U+221D", "&prop;", "Proportional To", "Math Symbols")
	AddCode("∞", "&#8734;", "\221E", "U+221E", "&infin;", "Infinity", "Math Symbols")
	AddCode("∟", "&#8735;", "\221F", "U+221F", "&angrt;", "Right Angle", "Math Symbols")
	AddCode("∠", "&#8736;", "\2220", "U+2220", "&ang;", "Angle", "Math Symbols")
	AddCode("∡", "&#8737;", "\2221", "U+2221", "&angmsd;", "Measured Angle", "Math Symbols")
	AddCode("∢", "&#8738;", "\2222", "U+2222", "&angsph;", "Spherical Angle", "Math Symbols")
	AddCode("∣", "&#8739;", "\2223", "U+2223", "&mid;", "Divides", "Math Symbols")
	AddCode("∤", "&#8740;", "\2224", "U+2224", "&nmid;", "Does Not Divide", "Math Symbols")
	AddCode("∥", "&#8741;", "\2225", "U+2225", "&parallel;", "Parallel To", "Math Symbols")
	AddCode("∦", "&#8742;", "\2226", "U+2226", "&npar;", "Not Parallel To", "Math Symbols")
	AddCode("∧", "&#8743;", "\2227", "U+2227", "&and;", "Logical And", "Math Symbols")
	AddCode("∨", "&#8744;", "\2228", "U+2228", "&or;", "Logical Or", "Math Symbols")
	AddCode("∩", "&#8745;", "\2229", "U+2229", "&cap;", "Intersection", "Math Symbols")
	AddCode("∪", "&#8746;", "\222A", "U+222A", "&cup;", "Union", "Math Symbols")
	AddCode("∫", "&#8747;", "\222B", "U+222B", "&int;", "Integral", "Math Symbols")
	AddCode("∬", "&#8748;", "\222C", "U+222C", "&Int;", "Double Integral", "Math Symbols")
	AddCode("∭", "&#8749;", "\222D", "U+222D", "&iiint;", "Triple Integral", "Math Symbols")
	AddCode("∮", "&#8750;", "\222E", "U+222E", "&conint;", "Contour Integral", "Math Symbols")
	AddCode("∯", "&#8751;", "\222F", "U+222F", "&Conint;", "Surface Integral", "Math Symbols")
	AddCode("∰", "&#8752;", "\2230", "U+2230", "&Cconint;", "Volume Integral", "Math Symbols")
	AddCode("∱", "&#8753;", "\2231", "U+2231", "&cwint;", "Clockwise Integral", "Math Symbols")
	AddCode("∲", "&#8754;", "\2232", "U+2232", "&cwconint;", "Clockwise Contour Integral", "Math Symbols")
	AddCode("∳", "&#8755;", "\2233", "U+2233", "&awconint;", "Anticlockwise Contour Integral", "Math Symbols")
	AddCode("∴", "&#8756;", "\2234", "U+2234", "&there4;", "Therefore", "Math Symbols")
	AddCode("∵", "&#8757;", "\2235", "U+2235", "&because;", "Because", "Math Symbols")
	AddCode("∶", "&#8758;", "\2236", "U+2236", "&ratio;", "Ratio", "Math Symbols")
	AddCode("∷", "&#8759;", "\2237", "U+2237", "&Colon;", "Proportion", "Math Symbols")
	AddCode("∸", "&#8760;", "\2238", "U+2238", "&minusd;", "Dot Minus", "Math Symbols")
	AddCode("∺", "&#8762;", "\223A", "U+223A", "&mDDot;", "Geometric Proportion", "Math Symbols")
	AddCode("∻", "&#8763;", "\223B", "U+223B", "&homtht;", "Homothetic", "Math Symbols")
	AddCode("∼", "&#8764;", "\223C", "U+223C", "&sim;", "Tilde Operator", "Math Symbols")
	AddCode("∽", "&#8765;", "\223D", "U+223D", "&bsim;", "Reversed Tilde", "Math Symbols")
	AddCode("∾", "&#8766;", "\223E", "U+223E", "&ac;", "Inverted Lazy S", "Math Symbols")
	AddCode("∿", "&#8767;", "\223F", "U+223F", "&acd;", "Sine Wave", "Math Symbols")
	AddCode("≀", "&#8768;", "\2240", "U+2240", "&wreath;", "Wreath Product", "Math Symbols")
	AddCode("≁", "&#8769;", "\2241", "U+2241", "&nsim;", "Not Tilde", "Math Symbols")
	AddCode("≂", "&#8770;", "\2242", "U+2242", "&esim;", "Minus Tilde", "Math Symbols")
	AddCode("≃", "&#8771;", "\2243", "U+2243", "&sime;", "Asymptotically Equal To", "Math Symbols")
	AddCode("≄", "&#8772;", "\2244", "U+2244", "&nsime;", "Not Asymptotically Equal To", "Math Symbols")
	AddCode("≅", "&#8773;", "\2245", "U+2245", "&cong;", "Approximately Equal To", "Math Symbols")
	AddCode("≆", "&#8774;", "\2246", "U+2246", "&simne;", "Approximately But Not Actually Equal To", "Math Symbols")
	AddCode("≇", "&#8775;", "\2247", "U+2247", "&ncong;", "Neither Approximately nor Actually Equal To", "Math Symbols")
	AddCode("≈", "&#8776;", "\2248", "U+2248", "&asymp;", "Almost Equal To", "Math Symbols")
	AddCode("≉", "&#8777;", "\2249", "U+2249", "&nap;", "Not Almost Equal To", "Math Symbols")
	AddCode("≊", "&#8778;", "\224A", "U+224A", "&approxeq;", "Almost Equal or Equal To", "Math Symbols")
	AddCode("≋", "&#8779;", "\224B", "U+224B", "&apid;", "Triple Tilde", "Math Symbols")
	AddCode("≌", "&#8780;", "\224C", "U+224C", "&bcong;", "All Equal To", "Math Symbols")
	AddCode("≍", "&#8781;", "\224D", "U+224D", "&asympeq;", "Equivalent To", "Math Symbols")
	AddCode("≎", "&#8782;", "\224E", "U+224E", "&bump;", "Geometrically Equivalent To", "Math Symbols")
	AddCode("≏", "&#8783;", "\224F", "U+224F", "&bumpe;", "Difference Between", "Math Symbols")
	AddCode("≐", "&#8784;", "\2250", "U+2250", "&esdot;", "Approaches the Limit", "Math Symbols")
	AddCode("≑", "&#8785;", "\2251", "U+2251", "&eDot;", "Geometrically Equal To", "Math Symbols")
	AddCode("≒", "&#8786;", "\2252", "U+2252", "&efDot;", "Approximately Equal To or the Image Of", "Math Symbols")
	AddCode("≓", "&#8787;", "\2253", "U+2253", "&erDot;", "Image of or Approximately Equal To", "Math Symbols")
	AddCode("≔", "&#8788;", "\2254", "U+2254", "&colone;", "Colon Equals", "Math Symbols")
	AddCode("≕", "&#8789;", "\2255", "U+2255", "&ecolon;", "Equals Colon", "Math Symbols")
	AddCode("≖", "&#8790;", "\2256", "U+2256", "&ecir;", "Ring In Equal To", "Math Symbols")
	AddCode("≗", "&#8791;", "\2257", "U+2257", "&cire;", "Ring Equal To", "Math Symbols")
	AddCode("≙", "&#8793;", "\2259", "U+2259", "&wedgeq;", "Estimates", "Math Symbols")
	AddCode("≚", "&#8794;", "\225A", "U+225A", "&veeeq;", "Equiangular To", "Math Symbols")
	AddCode("≜", "&#8796;", "\225C", "U+225C", "&trie;", "Delta Equal To", "Math Symbols")
	AddCode("≟", "&#8799;", "\225F", "U+225F", "&equest;", "Questioned Equal To", "Math Symbols")
	AddCode("≡", "&#8801;", "\2261", "U+2261", "&equiv;", "Identical To", "Math Symbols")
	AddCode("≢", "&#8802;", "\2262", "U+2262", "&nequiv;", "Not Identical To", "Math Symbols")
	AddCode("≤", "&#8804;", "\2264", "U+2264", "&le;", "Less-Than or Equal To", "Math Symbols")
	AddCode("≥", "&#8805;", "\2265", "U+2265", "&ge;", "Greater-Than or Equal To", "Math Symbols")
	AddCode("≦", "&#8806;", "\2266", "U+2266", "&lE;", "Less-Than Over Equal To", "Math Symbols")
	AddCode("≧", "&#8807;", "\2267", "U+2267", "&gE;", "Greater-Than Over Equal To", "Math Symbols")
	AddCode("≨", "&#8808;", "\2268", "U+2268", "&lnE;", "Less-Than But Not Equal To", "Math Symbols")
	AddCode("≩", "&#8809;", "\2269", "U+2269", "&gnE;", "Greater-Than But Not Equal To", "Math Symbols")
	AddCode("≪", "&#8810;", "\226A", "U+226A", "&Lt;", "Much Less-Than", "Math Symbols")
	AddCode("≫", "&#8811;", "\226B", "U+226B", "&Gt;", "Much Greater-Than", "Math Symbols")
	AddCode("≬", "&#8812;", "\226C", "U+226C", "&between;", "Between", "Math Symbols")
	AddCode("≭", "&#8813;", "\226D", "U+226D", "&NotCupCap;", "Not Equivalent To", "Math Symbols")
	AddCode("≮", "&#8814;", "\226E", "U+226E", "&nlt;", "Not Less-Than", "Math Symbols")
	AddCode("≯", "&#8815;", "\226F", "U+226F", "&ngt;", "Not Greater-Than", "Math Symbols")
	AddCode("≰", "&#8816;", "\2270", "U+2270", "&nle;", "Neither Less-Than nor Equal To", "Math Symbols")
	AddCode("≱", "&#8817;", "\2271", "U+2271", "&nge;", "Neither Greater-Than nor Equal To", "Math Symbols")
	AddCode("≲", "&#8818;", "\2272", "U+2272", "&lsim;", "Less-Than or Equivalent To", "Math Symbols")
	AddCode("≳", "&#8819;", "\2273", "U+2273", "&gsim;", "Greater-Than or Equivalent To", "Math Symbols")
	AddCode("≴", "&#8820;", "\2274", "U+2274", "&nlsim;", "Neither Less-Than nor Equivalent To", "Math Symbols")
	AddCode("≵", "&#8821;", "\2275", "U+2275", "&ngsim;", "Neither Greater-Than nor Equivalent To", "Math Symbols")
	AddCode("≶", "&#8822;", "\2276", "U+2276", "&lg;", "Less-Than or Greater-Than", "Math Symbols")
	AddCode("≷", "&#8823;", "\2277", "U+2277", "&gl;", "Greater-Than or Less-Than", "Math Symbols")
	AddCode("≸", "&#8824;", "\2278", "U+2278", "&ntlg;", "Neither Less-Than nor Greater-Than", "Math Symbols")
	AddCode("≹", "&#8825;", "\2279", "U+2279", "&ntgl;", "Neither Greater-Than nor Less-Than", "Math Symbols")
	AddCode("≺", "&#8826;", "\227A", "U+227A", "&pr;", "Precedes", "Math Symbols")
	AddCode("≻", "&#8827;", "\227B", "U+227B", "&sc;", "Succeeds", "Math Symbols")
	AddCode("≼", "&#8828;", "\227C", "U+227C", "&prcue;", "Precedes or Equal To", "Math Symbols")
	AddCode("≽", "&#8829;", "\227D", "U+227D", "&sccue;", "Succeeds or Equal To", "Math Symbols")
	AddCode("≾", "&#8830;", "\227E", "U+227E", "&prsim;", "Precedes or Equivalent To", "Math Symbols")
	AddCode("≿", "&#8831;", "\227F", "U+227F", "&scsim;", "Succeeds or Equivalent To", "Math Symbols")
	AddCode("⊀", "&#8832;", "\2280", "U+2280", "&npr;", "Does Not Precede", "Math Symbols")
	AddCode("⊁", "&#8833;", "\2281", "U+2281", "&nsc;", "Does Not Succeed", "Math Symbols")

End Sub

Private Sub AddCodes2

	AddCode("⊂", "&#8834;", "\2282", "U+2282", "&sub;", "Subset Of", "Math Symbols")
	AddCode("⊃", "&#8835;", "\2283", "U+2283", "&sup;", "Superset Of", "Math Symbols")
	AddCode("⊄", "&#8836;", "\2284", "U+2284", "&nsub;", "Not a Subset Of", "Math Symbols")
	AddCode("⊅", "&#8837;", "\2285", "U+2285", "&nsup;", "Not a Superset Of", "Math Symbols")
	AddCode("⊆", "&#8838;", "\2286", "U+2286", "&sube;", "Subset of or Equal To", "Math Symbols")
	AddCode("⊇", "&#8839;", "\2287", "U+2287", "&supe;", "Superset of or Equal To", "Math Symbols")
	AddCode("⊈", "&#8840;", "\2288", "U+2288", "&nsube;", "Neither a Subset of nor Equal To", "Math Symbols")
	AddCode("⊉", "&#8841;", "\2289", "U+2289", "&nsupe;", "Neither a Superset of nor Equal To", "Math Symbols")
	AddCode("⊊", "&#8842;", "\228A", "U+228A", "&subne;", "Subset of with Not Equal To", "Math Symbols")
	AddCode("⊋", "&#8843;", "\228B", "U+228B", "&supne;", "Superset of with Not Equal To", "Math Symbols")
	AddCode("⊍", "&#8845;", "\228D", "U+228D", "&cupdot;", "Multiset Multiplication", "Math Symbols")
	AddCode("⊎", "&#8846;", "\228E", "U+228E", "&uplus;", "Multiset Union", "Math Symbols")
	AddCode("⊏", "&#8847;", "\228F", "U+228F", "&sqsub;", "Square Image Of", "Math Symbols")
	AddCode("⊐", "&#8848;", "\2290", "U+2290", "&sqsup;", "Square Original Of", "Math Symbols")
	AddCode("⊑", "&#8849;", "\2291", "U+2291", "&sqsube;", "Square Image of or Equal To", "Math Symbols")
	AddCode("⊒", "&#8850;", "\2292", "U+2292", "&sqsupe;", "Square Original of or Equal To", "Math Symbols")
	AddCode("⊓", "&#8851;", "\2293", "U+2293", "&sqcap;", "Square Cap", "Math Symbols")
	AddCode("⊔", "&#8852;", "\2294", "U+2294", "&sqcup;", "Square Cup", "Math Symbols")
	AddCode("⊕", "&#8853;", "\2295", "U+2295", "&oplus;", "Circled Plus", "Math Symbols")
	AddCode("⊖", "&#8854;", "\2296", "U+2296", "&ominus;", "Circled Minus", "Math Symbols")
	AddCode("⊗", "&#8855;", "\2297", "U+2297", "&otimes;", "Circled Times", "Math Symbols")
	AddCode("⊘", "&#8856;", "\2298", "U+2298", "&osol;", "Circled Division Slash", "Math Symbols")
	AddCode("⊙", "&#8857;", "\2299", "U+2299", "&odot;", "Circled Dot Operator", "Math Symbols")
	AddCode("⊚", "&#8858;", "\229A", "U+229A", "&ocir;", "Circled Ring Operator", "Math Symbols")
	AddCode("⊛", "&#8859;", "\229B", "U+229B", "&oast;", "Circled Asterisk Operator", "Math Symbols")
	AddCode("⊝", "&#8861;", "\229D", "U+229D", "&odash;", "Circled Dash", "Math Symbols")
	AddCode("⊞", "&#8862;", "\229E", "U+229E", "&plusb;", "Squared Plus", "Math Symbols")
	AddCode("⊟", "&#8863;", "\229F", "U+229F", "&minusb;", "Squared Minus", "Math Symbols")
	AddCode("⊠", "&#8864;", "\22A0", "U+22A0", "&timesb;", "Squared Times", "Math Symbols")
	AddCode("⊡", "&#8865;", "\22A1", "U+22A1", "&sdotb;", "Squared Dot Operator", "Math Symbols")
	AddCode("⊢", "&#8866;", "\22A2", "U+22A2", "&vdash;", "Right Tack", "Math Symbols")
	AddCode("⊣", "&#8867;", "\22A3", "U+22A3", "&dashv;", "Left Tack", "Math Symbols")
	AddCode("⊤", "&#8868;", "\22A4", "U+22A4", "&top;", "Down Tack", "Math Symbols")
	AddCode("⊥", "&#8869;", "\22A5", "U+22A5", "&perp;", "Up Tack", "Math Symbols")
	AddCode("⊧", "&#8871;", "\22A7", "U+22A7", "&models;", "Models", "Math Symbols")
	AddCode("⊨", "&#8872;", "\22A8", "U+22A8", "&vDash;", "True", "Math Symbols")
	AddCode("⊩", "&#8873;", "\22A9", "U+22A9", "&Vdash;", "Forces", "Math Symbols")
	AddCode("⊪", "&#8874;", "\22AA", "U+22AA", "&Vvdash;", "Triple Vertical Bar Right Turnstile", "Math Symbols")
	AddCode("⊫", "&#8875;", "\22AB", "U+22AB", "&VDash;", "Double Vertical Bar Double Right Turnstile", "Math Symbols")
	AddCode("⊬", "&#8876;", "\22AC", "U+22AC", "&nvdash;", "Does Not Prove", "Math Symbols")
	AddCode("⊭", "&#8877;", "\22AD", "U+22AD", "&nvDash;", "Not True", "Math Symbols")
	AddCode("⊮", "&#8878;", "\22AE", "U+22AE", "&nVdash;", "Does Not Force", "Math Symbols")
	AddCode("⊯", "&#8879;", "\22AF", "U+22AF", "&nVDash;", "Negated Double Vertical Bar Double Right Turnstile", "Math Symbols")
	AddCode("⊰", "&#8880;", "\22B0", "U+22B0", "&prurel;", "Precedes Under Relation", "Math Symbols")
	AddCode("⊲", "&#8882;", "\22B2", "U+22B2", "&vltri;", "Normal Subgroup Of", "Math Symbols")
	AddCode("⊳", "&#8883;", "\22B3", "U+22B3", "&vrtri;", "Contains As Normal Subgroup", "Math Symbols")
	AddCode("⊴", "&#8884;", "\22B4", "U+22B4", "&ltrie;", "Normal Subgroup of or Equal To", "Math Symbols")
	AddCode("⊵", "&#8885;", "\22B5", "U+22B5", "&rtrie;", "Contains As Normal Subgroup or Equal To", "Math Symbols")
	AddCode("⊶", "&#8886;", "\22B6", "U+22B6", "&origof;", "Original Of", "Math Symbols")
	AddCode("⊷", "&#8887;", "\22B7", "U+22B7", "&imof;", "Image Of", "Math Symbols")
	AddCode("⊸", "&#8888;", "\22B8", "U+22B8", "&mumap;", "Multimap", "Math Symbols")
	AddCode("⊹", "&#8889;", "\22B9", "U+22B9", "&hercon;", "Hermitian Conjugate Matrix", "Math Symbols")
	AddCode("⊺", "&#8890;", "\22BA", "U+22BA", "&intcal;", "Intercalate", "Math Symbols")
	AddCode("⊻", "&#8891;", "\22BB", "U+22BB", "&veebar;", "Xor", "Math Symbols")
	AddCode("⊽", "&#8893;", "\22BD", "U+22BD", "&barvee;", "Nor", "Math Symbols")
	AddCode("⊾", "&#8894;", "\22BE", "U+22BE", "&angrtvb;", "Right Angle with Arc", "Math Symbols")
	AddCode("⊿", "&#8895;", "\22BF", "U+22BF", "&lrtri;", "Right Triangle", "Math Symbols")
	AddCode("⋀", "&#8896;", "\22C0", "U+22C0", "&xwedge;", "N-Ary Logical And", "Math Symbols")
	AddCode("⋁", "&#8897;", "\22C1", "U+22C1", "&xvee;", "N-Ary Logical Or", "Math Symbols")
	AddCode("⋂", "&#8898;", "\22C2", "U+22C2", "&xcap;", "N-Ary Intersection", "Math Symbols")
	AddCode("⋃", "&#8899;", "\22C3", "U+22C3", "&xcup;", "N-Ary Union", "Math Symbols")
	AddCode("⋄", "&#8900;", "\22C4", "U+22C4", "&diamond;", "Diamond Operator", "Math Symbols")
	AddCode("⋅", "&#8901;", "\22C5", "U+22C5", "&sdot;", "Dot Operator", "Math Symbols")
	AddCode("⋆", "&#8902;", "\22C6", "U+22C6", "&Star;", "Star Operator", "Math Symbols")
	AddCode("⋇", "&#8903;", "\22C7", "U+22C7", "&divonx;", "Division Times", "Math Symbols")
	AddCode("⋈", "&#8904;", "\22C8", "U+22C8", "&bowtie;", "Bowtie", "Math Symbols")
	AddCode("⋉", "&#8905;", "\22C9", "U+22C9", "&ltimes;", "Left Normal Factor Semidirect Product", "Math Symbols")
	AddCode("⋊", "&#8906;", "\22CA", "U+22CA", "&rtimes;", "Right Normal Factor Semidirect Product", "Math Symbols")
	AddCode("⋋", "&#8907;", "\22CB", "U+22CB", "&lthree;", "Left Semidirect Product", "Math Symbols")
	AddCode("⋌", "&#8908;", "\22CC", "U+22CC", "&rthree;", "Right Semidirect Product", "Math Symbols")
	AddCode("⋍", "&#8909;", "\22CD", "U+22CD", "&bsime;", "Reversed Tilde Equals", "Math Symbols")
	AddCode("⋎", "&#8910;", "\22CE", "U+22CE", "&cuvee;", "Curly Logical Or", "Math Symbols")
	AddCode("⋏", "&#8911;", "\22CF", "U+22CF", "&cuwed;", "Curly Logical And", "Math Symbols")
	AddCode("⋐", "&#8912;", "\22D0", "U+22D0", "&Sub;", "Double Subset", "Math Symbols")
	AddCode("⋑", "&#8913;", "\22D1", "U+22D1", "&Sup;", "Double Superset", "Math Symbols")
	AddCode("⋒", "&#8914;", "\22D2", "U+22D2", "&Cap;", "Double Intersection", "Math Symbols")
	AddCode("⋓", "&#8915;", "\22D3", "U+22D3", "&Cup;", "Double Union", "Math Symbols")
	AddCode("⋔", "&#8916;", "\22D4", "U+22D4", "&fork;", "Pitchfork", "Math Symbols")
	AddCode("⋕", "&#8917;", "\22D5", "U+22D5", "&epar;", "Equal and Parallel To", "Math Symbols")
	AddCode("⋖", "&#8918;", "\22D6", "U+22D6", "&ltdot;", "Less-Than with Dot", "Math Symbols")
	AddCode("⋗", "&#8919;", "\22D7", "U+22D7", "&gtdot;", "Greater-Than with Dot", "Math Symbols")
	AddCode("⋘", "&#8920;", "\22D8", "U+22D8", "&Ll;", "Very Much Less-Than", "Math Symbols")
	AddCode("⋙", "&#8921;", "\22D9", "U+22D9", "&Gg;", "Very Much Greater-Than", "Math Symbols")
	AddCode("⋚", "&#8922;", "\22DA", "U+22DA", "&leg;", "Less-Than Equal To or Greater-Than", "Math Symbols")
	AddCode("⋛", "&#8923;", "\22DB", "U+22DB", "&gel;", "Greater-Than Equal To or Less-Than", "Math Symbols")
	AddCode("⋞", "&#8926;", "\22DE", "U+22DE", "&cuepr;", "Equal To or Precedes", "Math Symbols")
	AddCode("⋟", "&#8927;", "\22DF", "U+22DF", "&cuesc;", "Equal To or Succeeds", "Math Symbols")
	AddCode("⋠", "&#8928;", "\22E0", "U+22E0", "&nprcue;", "Does Not Precede or Equal", "Math Symbols")
	AddCode("⋡", "&#8929;", "\22E1", "U+22E1", "&nsccue;", "Does Not Succeed or Equal", "Math Symbols")
	AddCode("⋢", "&#8930;", "\22E2", "U+22E2", "&nsqsube;", "Not Square Image of or Equal To", "Math Symbols")
	AddCode("⋣", "&#8931;", "\22E3", "U+22E3", "&nsqsupe;", "Not Square Original of or Equal To", "Math Symbols")
	AddCode("⋦", "&#8934;", "\22E6", "U+22E6", "&lnsim;", "Less-Than But Not Equivalent To", "Math Symbols")
	AddCode("⋧", "&#8935;", "\22E7", "U+22E7", "&gnsim;", "Greater-Than But Not Equivalent To", "Math Symbols")
	AddCode("⋨", "&#8936;", "\22E8", "U+22E8", "&prnsim;", "Precedes But Not Equivalent To", "Math Symbols")
	AddCode("⋩", "&#8937;", "\22E9", "U+22E9", "&scnsim;", "Succeeds But Not Equivalent To", "Math Symbols")
	AddCode("⋪", "&#8938;", "\22EA", "U+22EA", "&nltri;", "Not Normal Subgroup Of", "Math Symbols")
	AddCode("⋫", "&#8939;", "\22EB", "U+22EB", "&nrtri;", "Does Not Contain As Normal Subgroup", "Math Symbols")
	AddCode("⋬", "&#8940;", "\22EC", "U+22EC", "&nltrie;", "Not Normal Subgroup of or Equal To", "Math Symbols")
	AddCode("⋭", "&#8941;", "\22ED", "U+22ED", "&nrtrie;", "Does Not Contain As Normal Subgroup or Equal", "Math Symbols")
	AddCode("⋮", "&#8942;", "\22EE", "U+22EE", "&vellip;", "Vertical Ellipsis", "Math Symbols")
	AddCode("⋯", "&#8943;", "\22EF", "U+22EF", "&ctdot;", "Midline Horizontal Ellipsis", "Math Symbols")
	AddCode("⋰", "&#8944;", "\22F0", "U+22F0", "&utdot;", "Up Right Diagonal Ellipsis", "Math Symbols")
	AddCode("⋱", "&#8945;", "\22F1", "U+22F1", "&dtdot;", "Down Right Diagonal Ellipsis", "Math Symbols")
	AddCode("⋲", "&#8946;", "\22F2", "U+22F2", "&disin;", "Element of with Long Horizontal Stroke", "Math Symbols")
	AddCode("⋳", "&#8947;", "\22F3", "U+22F3", "&isinsv;", "Element of with Vertical Bar At End of Horizontal Stroke", "Math Symbols")
	AddCode("⋴", "&#8948;", "\22F4", "U+22F4", "&isins;", "Small Element of with Vertical Bar At End of Horizontal Stroke", "Math Symbols")
	AddCode("⋵", "&#8949;", "\22F5", "U+22F5", "&isindot;", "Element of with Dot Above", "Math Symbols")
	AddCode("⋶", "&#8950;", "\22F6", "U+22F6", "&notinvc;", "Element of with Overbar", "Math Symbols")
	AddCode("⋷", "&#8951;", "\22F7", "U+22F7", "&notinvb;", "Small Element of with Overbar", "Math Symbols")
	AddCode("⋹", "&#8953;", "\22F9", "U+22F9", "&isinE;", "Element of with Two Horizontal Strokes", "Math Symbols")
	AddCode("⋺", "&#8954;", "\22FA", "U+22FA", "&nisd;", "Contains with Long Horizontal Stroke", "Math Symbols")
	AddCode("⋻", "&#8955;", "\22FB", "U+22FB", "&xnis;", "Contains with Vertical Bar At End of Horizontal Stroke", "Math Symbols")
	AddCode("⋼", "&#8956;", "\22FC", "U+22FC", "&nis;", "Small Contains with Vertical Bar At End of Horizontal Stroke", "Math Symbols")
	AddCode("⋽", "&#8957;", "\22FD", "U+22FD", "&notnivc;", "Contains with Overbar", "Math Symbols")
	AddCode("⋾", "&#8958;", "\22FE", "U+22FE", "&notnivb;", "Small Contains with Overbar", "Math Symbols")
	AddCode("⌈", "&#8968;", "\2308", "U+2308", "&lceil;", "Left Ceiling", "Math Symbols")
	AddCode("⌉", "&#8969;", "\2309", "U+2309", "&rceil;", "Right Ceiling", "Math Symbols")
	AddCode("⌊", "&#8970;", "\230A", "U+230A", "&lfloor;", "Left Floor", "Math Symbols")
	AddCode("⌋", "&#8971;", "\230B", "U+230B", "&rfloor;", "Right Floor", "Math Symbols")
	AddCode("〈", "&#9001;", "\2329", "U+2329", "&lang;", "Left-Pointing Angle Bracket", "Math Symbols")
	AddCode("〉", "&#9002;", "\232A", "U+232A", "&rang;", "Right-Pointing Angle Bracket", "Math Symbols")
	AddCode("Α", "&#913;", "\0391", "U+0391", "&Alpha;", "Greek Capital Letter Alpha", "Greek Letters")
	AddCode("Β", "&#914;", "\0392", "U+0392", "&Beta;", "Greek Capital Letter Beta", "Greek Letters")
	AddCode("Γ", "&#915;", "\0393", "U+0393", "&Gamma;", "Greek Capital Letter Gamma", "Greek Letters")
	AddCode("Δ", "&#916;", "\0394", "U+0394", "&Delta;", "Greek Capital Letter Delta", "Greek Letters")
	AddCode("Ε", "&#917;", "\0395", "U+0395", "&Epsilon;", "Greek Capital Letter Epsilon", "Greek Letters")
	AddCode("Ζ", "&#918;", "\0396", "U+0396", "&Zeta;", "Greek Capital Letter Zeta", "Greek Letters")
	AddCode("Η", "&#919;", "\0397", "U+0397", "&Eta;", "Greek Capital Letter Eta", "Greek Letters")
	AddCode("Θ", "&#920;", "\0398", "U+0398", "&Theta;", "Greek Capital Letter Theta", "Greek Letters")
	AddCode("Ι", "&#921;", "\0399", "U+0399", "&Iota;", "Greek Capital Letter Iota", "Greek Letters")
	AddCode("Κ", "&#922;", "\039A", "U+039A", "&Kappa;", "Greek Capital Letter Kappa", "Greek Letters")
	AddCode("Λ", "&#923;", "\039B", "U+039B", "&Lambda;", "Greek Capital Letter Lamda", "Greek Letters")
	AddCode("Μ", "&#924;", "\039C", "U+039C", "&Mu;", "Greek Capital Letter Mu", "Greek Letters")
	AddCode("Ν", "&#925;", "\039D", "U+039D", "&Nu;", "Greek Capital Letter Nu", "Greek Letters")
	AddCode("Ξ", "&#926;", "\039E", "U+039E", "&Xi;", "Greek Capital Letter Xi", "Greek Letters")
	AddCode("Ο", "&#927;", "\039F", "U+039F", "&Omicron;", "Greek Capital Letter Omicron", "Greek Letters")
	AddCode("Π", "&#928;", "\03A0", "U+03A0", "&Pi;", "Greek Capital Letter Pi", "Greek Letters")
	AddCode("Ρ", "&#929;", "\03A1", "U+03A1", "&Rho;", "Greek Capital Letter Rho", "Greek Letters")
	AddCode("Σ", "&#931;", "\03A3", "U+03A3", "&Sigma;", "Greek Capital Letter Sigma", "Greek Letters")
	AddCode("Τ", "&#932;", "\03A4", "U+03A4", "&Tau;", "Greek Capital Letter Tau", "Greek Letters")
	AddCode("Υ", "&#933;", "\03A5", "U+03A5", "&Upsilon;", "Greek Capital Letter Upsilon", "Greek Letters")
	AddCode("Φ", "&#934;", "\03A6", "U+03A6", "&Phi;", "Greek Capital Letter Phi", "Greek Letters")
	AddCode("Χ", "&#935;", "\03A7", "U+03A7", "&Chi;", "Greek Capital Letter Chi", "Greek Letters")
	AddCode("Ψ", "&#936;", "\03A8", "U+03A8", "&Psi;", "Greek Capital Letter Psi", "Greek Letters")
	AddCode("Ω", "&#937;", "\03A9", "U+03A9", "&Omega;", "Greek Capital Letter Omega", "Greek Letters")
	AddCode("α", "&#945;", "\03B1", "U+03B1", "&alpha;", "Greek Small Letter Alpha", "Greek Letters")
	AddCode("β", "&#946;", "\03B2", "U+03B2", "&beta;", "Greek Small Letter Beta", "Greek Letters")
	AddCode("γ", "&#947;", "\03B3", "U+03B3", "&gamma;", "Greek Small Letter Gamma", "Greek Letters")
	AddCode("δ", "&#948;", "\03B4", "U+03B4", "&delta;", "Greek Small Letter Delta", "Greek Letters")
	AddCode("ε", "&#949;", "\03B5", "U+03B5", "&epsilon;", "Greek Small Letter Epsilon", "Greek Letters")
	AddCode("ζ", "&#950;", "\03B6", "U+03B6", "&zeta;", "Greek Small Letter Zeta", "Greek Letters")
	AddCode("η", "&#951;", "\03B7", "U+03B7", "&eta;", "Greek Small Letter Eta", "Greek Letters")
	AddCode("θ", "&#952;", "\03B8", "U+03B8", "&theta;", "Greek Small Letter Theta", "Greek Letters")
	AddCode("ι", "&#953;", "\03B9", "U+03B9", "&iota;", "Greek Small Letter Iota", "Greek Letters")
	AddCode("κ", "&#954;", "\03BA", "U+03BA", "&kappa;", "Greek Small Letter Kappa", "Greek Letters")
	AddCode("λ", "&#955;", "\03BB", "U+03BB", "&lambda;", "Greek Small Letter Lamda", "Greek Letters")
	AddCode("μ", "&#956;", "\03BC", "U+03BC", "&mu;", "Greek Small Letter Mu", "Greek Letters")
	AddCode("ν", "&#957;", "\03BD", "U+03BD", "&nu;", "Greek Small Letter Nu", "Greek Letters")
	AddCode("ξ", "&#958;", "\03BE", "U+03BE", "&xi;", "Greek Small Letter Xi", "Greek Letters")
	AddCode("ο", "&#959;", "\03BF", "U+03BF", "&omicron;", "Greek Small Letter Omicron", "Greek Letters")
	AddCode("π", "&#960;", "\03C0", "U+03C0", "&pi;", "Greek Small Letter Pi", "Greek Letters")
	AddCode("ρ", "&#961;", "\03C1", "U+03C1", "&rho;", "Greek Small Letter Rho", "Greek Letters")
	AddCode("ς", "&#962;", "\03C2", "U+03C2", "&sigmaf;", "Greek Small Letter Final Sigma", "Greek Letters")
	AddCode("σ", "&#963;", "\03C3", "U+03C3", "&sigma;", "Greek Small Letter Sigma", "Greek Letters")
	AddCode("τ", "&#964;", "\03C4", "U+03C4", "&tau;", "Greek Small Letter Tau", "Greek Letters")
	AddCode("υ", "&#965;", "\03C5", "U+03C5", "&upsilon;", "Greek Small Letter Upsilon", "Greek Letters")
	AddCode("φ", "&#966;", "\03C6", "U+03C6", "&phi;", "Greek Small Letter Phi", "Greek Letters")
	AddCode("χ", "&#967;", "\03C7", "U+03C7", "&chi;", "Greek Small Letter Chi", "Greek Letters")
	AddCode("ψ", "&#968;", "\03C8", "U+03C8", "&psi;", "Greek Small Letter Psi", "Greek Letters")
	AddCode("ω", "&#969;", "\03C9", "U+03C9", "&omega;", "Greek Small Letter Omega", "Greek Letters")
	AddCode("ϑ", "&#977;", "\03D1", "U+03D1", "&thetasym;", "Greek Theta Symbol", "Greek Letters")
	AddCode("ϒ", "&#978;", "\03D2", "U+03D2", "&upsih;", "Greek Upsilon with Hook Symbol", "Greek Letters")
	AddCode("ϖ", "&#982;", "\03D6", "U+03D6", "&piv;", "Greek Pi Symbol", "Greek Letters")
	AddCode("À", "&#192;", "\00C0", "U+00C0", "&Agrave;", "Latin Capital Letter a with Grave", "Latin Letters")
	AddCode("Á", "&#193;", "\00C1", "U+00C1", "&Aacute;", "Latin Capital Letter a with Acute", "Latin Letters")
	AddCode("Â", "&#194;", "\00C2", "U+00C2", "&Acirc;", "Latin Capital Letter a with Circumflex", "Latin Letters")
	AddCode("Ã", "&#195;", "\00C3", "U+00C3", "&Atilde;", "Latin Capital Letter a with Tilde", "Latin Letters")
	AddCode("Ä", "&#196;", "\00C4", "U+00C4", "&Auml;", "Latin Capital Letter a with Diaeresis", "Latin Letters")
	AddCode("Å", "&#197;", "\00C5", "U+00C5", "&Aring;", "Latin Capital Letter a with Ring Above", "Latin Letters")
	AddCode("Æ", "&#198;", "\00C6", "U+00C6", "&AElig;", "Latin Capital Letter Ae", "Latin Letters")
	AddCode("Ç", "&#199;", "\00C7", "U+00C7", "&Ccedil;", "Latin Capital Letter C with Cedilla", "Latin Letters")
	AddCode("È", "&#200;", "\00C8", "U+00C8", "&Egrave;", "Latin Capital Letter E with Grave", "Latin Letters")
	AddCode("É", "&#201;", "\00C9", "U+00C9", "&Eacute;", "Latin Capital Letter E with Acute", "Latin Letters")
	AddCode("Ê", "&#202;", "\00CA", "U+00CA", "&Ecirc;", "Latin Capital Letter E with Circumflex", "Latin Letters")
	AddCode("Ë", "&#203;", "\00CB", "U+00CB", "&Euml;", "Latin Capital Letter E with Diaeresis", "Latin Letters")
	AddCode("Ì", "&#204;", "\00CC", "U+00CC", "&Lgrave;", "Latin Capital Letter I with Grave", "Latin Letters")
	AddCode("Ĺ", "&#313;", "\0139", "U+0139", "&Lacute;", "Latin Capital Letter L with Acute", "Latin Letters")
	AddCode("Î", "&#206;", "\00CE", "U+00CE", "&Lcirc;", "Latin Capital Letter I with Circumflex", "Latin Letters")
	AddCode("Ï", "&#207;", "\00CF", "U+00CF", "&Luml;", "Latin Capital Letter I with Diaeresis", "Latin Letters")
	AddCode("Ð", "&#208;", "\00D0", "U+00D0", "&ETH;", "Latin Capital Letter Eth", "Latin Letters")
	AddCode("Ñ", "&#209;", "\00D1", "U+00D1", "&Ntilde;", "Latin Capital Letter N with Tilde", "Latin Letters")
	AddCode("Ò", "&#210;", "\00D2", "U+00D2", "&Ograve;", "Latin Capital Letter O with Grave", "Latin Letters")
	AddCode("Ó", "&#211;", "\00D3", "U+00D3", "&Oacute;", "Latin Capital Letter O with Acute", "Latin Letters")
	AddCode("Ô", "&#212;", "\00D4", "U+00D4", "&Ocirc;", "Latin Capital Letter O with Circumflex", "Latin Letters")
	AddCode("Õ", "&#213;", "\00D5", "U+00D5", "&Otilde;", "Latin Capital Letter O with Tilde", "Latin Letters")
	AddCode("Ö", "&#214;", "\00D6", "U+00D6", "&Ouml;", "Latin Capital Letter O with Diaeresis", "Latin Letters")
	AddCode("Ø", "&#216;", "\00D8", "U+00D8", "&Oslash;", "Latin Capital Letter O with Stroke", "Latin Letters")
	AddCode("Ù", "&#217;", "\00D9", "U+00D9", "&Ugrave;", "Latin Capital Letter U with Grave", "Latin Letters")
	AddCode("Ú", "&#218;", "\00DA", "U+00DA", "&Uacute;", "Latin Capital Letter U with Acute", "Latin Letters")
	AddCode("Û", "&#219;", "\00DB", "U+00DB", "&Ucirc;", "Latin Capital Letter U with Circumflex", "Latin Letters")
	AddCode("Ü", "&#220;", "\00DC", "U+00DC", "&Uuml;", "Latin Capital Letter U with Diaeresis", "Latin Letters")
	AddCode("Ý", "&#221;", "\00DD", "U+00DD", "&Yacute;", "Latin Capital Letter Y with Acute", "Latin Letters")
	AddCode("Þ", "&#222;", "\00DE", "U+00DE", "&THORN;", "Latin Capital Letter Thorn", "Latin Letters")
	AddCode("ß", "&#223;", "\00DF", "U+00DF", "&szlig;", "Latin Small Letter Sharp S", "Latin Letters")
	AddCode("à", "&#224;", "\00E0", "U+00E0", "&agrave;", "Latin Small Letter a with Grave", "Latin Letters")
	AddCode("á", "&#225;", "\00E1", "U+00E1", "&aacute;", "Latin Small Letter a with Acute", "Latin Letters")
	AddCode("â", "&#226;", "\00E2", "U+00E2", "&acirc;", "Latin Small Letter a with Circumflex", "Latin Letters")
	AddCode("ã", "&#227;", "\00E3", "U+00E3", "&atilde;", "Latin Small Letter a with Tilde", "Latin Letters")
	AddCode("ä", "&#228;", "\00E4", "U+00E4", "&auml;", "Latin Small Letter a with Diaeresis", "Latin Letters")
	AddCode("å", "&#229;", "\00E5", "U+00E5", "&aring;", "Latin Small Letter a with Ring Above", "Latin Letters")
	AddCode("æ", "&#230;", "\00E6", "U+00E6", "&aelig;", "Latin Small Letter Ae", "Latin Letters")
	AddCode("ç", "&#231;", "\00E7", "U+00E7", "&ccedil;", "Latin Small Letter C with Cedilla", "Latin Letters")
	AddCode("è", "&#232;", "\00E8", "U+00E8", "&egrave;", "Latin Small Letter E with Grave", "Latin Letters")
	AddCode("é", "&#233;", "\00E9", "U+00E9", "&eacute;", "Latin Small Letter E with Acute", "Latin Letters")
	AddCode("ê", "&#234;", "\00EA", "U+00EA", "&ecirc;", "Latin Small Letter E with Circumflex", "Latin Letters")
	AddCode("ë", "&#235;", "\00EB", "U+00EB", "&euml;", "Latin Small Letter E with Diaeresis", "Latin Letters")
	AddCode("ì", "&#236;", "\00EC", "U+00EC", "&igrave;", "Latin Small Letter I with Grave", "Latin Letters")
	AddCode("í", "&#237;", "\00ED", "U+00ED", "&iacute;", "Latin Small Letter I with Acute", "Latin Letters")
	AddCode("î", "&#238;", "\00EE", "U+00EE", "&icirc;", "Latin Small Letter I with Circumflex", "Latin Letters")
	AddCode("ï", "&#239;", "\00EF", "U+00EF", "&iuml;", "Latin Small Letter I with Diaeresis", "Latin Letters")
	AddCode("ð", "&#240;", "\00F0", "U+00F0", "&eth;", "Latin Small Letter Eth", "Latin Letters")
	AddCode("ñ", "&#241;", "\00F1", "U+00F1", "&ntilde;", "Latin Small Letter N with Tilde", "Latin Letters")
	AddCode("ò", "&#242;", "\00F2", "U+00F2", "&ograve;", "Latin Small Letter O with Grave", "Latin Letters")
	AddCode("ó", "&#243;", "\00F3", "U+00F3", "&oacute;", "Latin Small Letter O with Acute", "Latin Letters")
	AddCode("ô", "&#244;", "\00F4", "U+00F4", "&ocirc;", "Latin Small Letter O with Circumflex", "Latin Letters")
	AddCode("õ", "&#245;", "\00F5", "U+00F5", "&otilde;", "Latin Small Letter O with Tilde", "Latin Letters")
	AddCode("ö", "&#246;", "\00F6", "U+00F6", "&ouml;", "Latin Small Letter O with Diaeresis", "Latin Letters")
	AddCode("ø", "&#248;", "\00F8", "U+00F8", "&oslash;", "Latin Small Letter O with Stroke", "Latin Letters")
	AddCode("ù", "&#249;", "\00F9", "U+00F9", "&ugrave;", "Latin Small Letter U with Grave", "Latin Letters")
	AddCode("ú", "&#250;", "\00FA", "U+00FA", "&uacute;", "Latin Small Letter U with Acute", "Latin Letters")
	AddCode("û", "&#251;", "\00FB", "U+00FB", "&ucirc;", "Latin Small Letter U with Circumflex", "Latin Letters")
	AddCode("ü", "&#252;", "\00FC", "U+00FC", "&uuml;", "U with two Dots", "Latin Letters")
	AddCode("ý", "&#253;", "\00FD", "U+00FD", "&yacute;", "Latin Small Letter Y with Acute", "Latin Letters")
	AddCode("þ", "&#254;", "\00FE", "U+00FE", "&thorn;", "Latin Small Letter Thorn", "Latin Letters")
	AddCode("ÿ", "&#255;", "\00FF", "U+00FF", "&yuml;", "Latin Small Letter Y with Diaeresis", "Latin Letters")
	AddCode("Ā", "&#256;", "\0100", "U+0100", "&Amacr;", "Latin Capital Letter a with Macron", "Latin Letters")
	AddCode("ā", "&#257;", "\0101", "U+0101", "&amacr;", "Latin Small Letter a with Macron", "Latin Letters")
	AddCode("Ă", "&#258;", "\0102", "U+0102", "&Abreve;", "Latin Capital Letter a with Breve", "Latin Letters")
	AddCode("ă", "&#259;", "\0103", "U+0103", "&abreve;", "Latin Small Letter a with Breve", "Latin Letters")
	AddCode("Ą", "&#260;", "\0104", "U+0104", "&Aogon;", "Latin Capital Letter a with Ogonek", "Latin Letters")
	AddCode("ą", "&#261;", "\0105", "U+0105", "&aogon;", "Latin Small Letter a with Ogonek", "Latin Letters")
	AddCode("Ć", "&#262;", "\0106", "U+0106", "&Cacute;", "Latin Capital Letter C with Acute", "Latin Letters")
	AddCode("ć", "&#263;", "\0107", "U+0107", "&cacute;", "Latin Small Letter C with Acute", "Latin Letters")
	AddCode("Ĉ", "&#264;", "\0108", "U+0108", "&Ccirc;", "Latin Capital Letter C with Circumflex", "Latin Letters")
	AddCode("ĉ", "&#265;", "\0109", "U+0109", "&ccirc;", "Latin Small Letter C with Circumflex", "Latin Letters")
	AddCode("Ċ", "&#266;", "\010A", "U+010A", "&Cdot;", "Latin Capital Letter C with Dot Above", "Latin Letters")
	AddCode("ċ", "&#267;", "\010B", "U+010B", "&cdot;", "Latin Small Letter C with Dot Above", "Latin Letters")
	AddCode("Č", "&#268;", "\010C", "U+010C", "&Ccaron;", "Latin Capital Letter C with Caron", "Latin Letters")
	AddCode("č", "&#269;", "\010D", "U+010D", "&ccaron;", "Latin Small Letter C with Caron", "Latin Letters")
	AddCode("Ď", "&#270;", "\010E", "U+010E", "&Dcaron;", "Latin Capital Letter D with Caron", "Latin Letters")
	AddCode("ď", "&#271;", "\010F", "U+010F", "&dcaron;", "Latin Small Letter D with Caron", "Latin Letters")
	AddCode("Đ", "&#272;", "\0110", "U+0110", "&Dstrok;", "Latin Capital Letter D with Stroke", "Latin Letters")
	AddCode("đ", "&#273;", "\0111", "U+0111", "&dstrok;", "Latin Small Letter D with Stroke", "Latin Letters")
	AddCode("Ē", "&#274;", "\0112", "U+0112", "&Emacr;", "Latin Capital Letter E with Macron", "Latin Letters")
	AddCode("ē", "&#275;", "\0113", "U+0113", "&emacr;", "Latin Small Letter E with Macron", "Latin Letters")
	AddCode("Ė", "&#278;", "\0116", "U+0116", "&Edot;", "Latin Capital Letter E with Dot Above", "Latin Letters")
	AddCode("ė", "&#279;", "\0117", "U+0117", "&edot;", "Latin Small Letter E with Dot Above", "Latin Letters")
	AddCode("Ę", "&#280;", "\0118", "U+0118", "&Eogon;", "Latin Capital Letter E with Ogonek", "Latin Letters")
	AddCode("ę", "&#281;", "\0119", "U+0119", "&eogon;", "Latin Small Letter E with Ogonek", "Latin Letters")
	AddCode("Ě", "&#282;", "\011A", "U+011A", "&Ecaron;", "Latin Capital Letter E with Caron", "Latin Letters")
	AddCode("ě", "&#283;", "\011B", "U+011B", "&ecaron;", "Latin Small Letter E with Caron", "Latin Letters")
	AddCode("Ĝ", "&#284;", "\011C", "U+011C", "&Gcirc;", "Latin Capital Letter G with Circumflex", "Latin Letters")
	AddCode("ĝ", "&#285;", "\011D", "U+011D", "&gcirc;", "Latin Small Letter G with Circumflex", "Latin Letters")
	AddCode("Ğ", "&#286;", "\011E", "U+011E", "&Gbreve;", "Latin Capital Letter G with Breve", "Latin Letters")
	AddCode("ğ", "&#287;", "\011F", "U+011F", "&gbreve;", "Latin Small Letter G with Breve", "Latin Letters")
	AddCode("Ġ", "&#288;", "\0120", "U+0120", "&Gdot;", "Latin Capital Letter G with Dot Above", "Latin Letters")
	AddCode("ġ", "&#289;", "\0121", "U+0121", "&gdot;", "Latin Small Letter G with Dot Above", "Latin Letters")
	AddCode("Ģ", "&#290;", "\0122", "U+0122", "&Gcedil;", "Latin Capital Letter G with Cedilla", "Latin Letters")
	AddCode("Ĥ", "&#292;", "\0124", "U+0124", "&Hcirc;", "Latin Capital Letter H with Circumflex", "Latin Letters")
	AddCode("ĥ", "&#293;", "\0125", "U+0125", "&hcirc;", "Latin Small Letter H with Circumflex", "Latin Letters")
	AddCode("Ħ", "&#294;", "\0126", "U+0126", "&Hstrok;", "Latin Capital Letter H with Stroke", "Latin Letters")
	AddCode("ħ", "&#295;", "\0127", "U+0127", "&hstrok;", "Latin Small Letter H with Stroke", "Latin Letters")
	AddCode("Ĩ", "&#296;", "\0128", "U+0128", "&Itilde;", "Latin Capital Letter I with Tilde", "Latin Letters")
	AddCode("ĩ", "&#297;", "\0129", "U+0129", "&itilde;", "Latin Small Letter I with Tilde", "Latin Letters")
	AddCode("Ī", "&#298;", "\012A", "U+012A", "&Imacr;", "Latin Capital Letter I with Macron", "Latin Letters")
	AddCode("ī", "&#299;", "\012B", "U+012B", "&imacr;", "Latin Small Letter I with Macron", "Latin Letters")
	AddCode("Į", "&#302;", "\012E", "U+012E", "&Iogon;", "Latin Capital Letter I with Ogonek", "Latin Letters")
	AddCode("į", "&#303;", "\012F", "U+012F", "&iogon;", "Latin Small Letter I with Ogonek", "Latin Letters")
	AddCode("İ", "&#304;", "\0130", "U+0130", "&Idot;", "Latin Capital Letter I with Dot Above", "Latin Letters")
	AddCode("ı", "&#305;", "\0131", "U+0131", "&imath;", "Latin Small Letter Dotless I", "Latin Letters")
	AddCode("Ĳ", "&#306;", "\0132", "U+0132", "&IJlig;", "Latin Capital Ligature Ij", "Latin Letters")
	AddCode("ĳ", "&#307;", "\0133", "U+0133", "&ijlig;", "Latin Small Ligature Ij", "Latin Letters")
	AddCode("Ĵ", "&#308;", "\0134", "U+0134", "&Jcirc;", "Latin Capital Letter J with Circumflex", "Latin Letters")
	AddCode("ĵ", "&#309;", "\0135", "U+0135", "&jcirc;", "Latin Small Letter J with Circumflex", "Latin Letters")
	AddCode("Ķ", "&#310;", "\0136", "U+0136", "&Kcedil;", "Latin Capital Letter K with Cedilla", "Latin Letters")
	AddCode("ķ", "&#311;", "\0137", "U+0137", "&kcedil;", "Latin Small Letter K with Cedilla", "Latin Letters")
	AddCode("ĸ", "&#312;", "\0138", "U+0138", "&kgreen;", "Latin Small Letter Kra", "Latin Letters")
	AddCode("ĺ", "&#314;", "\013A", "U+013A", "&lacute;", "Latin Small Letter L with Acute", "Latin Letters")
	AddCode("Ļ", "&#315;", "\013B", "U+013B", "&Lcedil;", "Latin Capital Letter L with Cedilla", "Latin Letters")
	AddCode("ļ", "&#316;", "\013C", "U+013C", "&lcedil;", "Latin Small Letter L with Cedilla", "Latin Letters")
	AddCode("Ľ", "&#317;", "\013D", "U+013D", "&Lcaron;", "Latin Capital Letter L with Caron", "Latin Letters")
	AddCode("ľ", "&#318;", "\013E", "U+013E", "&lcaron;", "Latin Small Letter L with Caron", "Latin Letters")
	AddCode("Ŀ", "&#319;", "\013F", "U+013F", "&Lmidot;", "Latin Capital Letter L with Middle Dot", "Latin Letters")
	AddCode("ŀ", "&#320;", "\0140", "U+0140", "&lmidot;", "Latin Small Letter L with Middle Dot", "Latin Letters")
	AddCode("Ł", "&#321;", "\0141", "U+0141", "&Lstrok;", "Latin Capital Letter L with Stroke", "Latin Letters")
	AddCode("ł", "&#322;", "\0142", "U+0142", "&lstrok;", "Latin Small Letter L with Stroke", "Latin Letters")
	AddCode("Ń", "&#323;", "\0143", "U+0143", "&Nacute;", "Latin Capital Letter N with Acute", "Latin Letters")
	AddCode("ń", "&#324;", "\0144", "U+0144", "&nacute;", "Latin Small Letter N with Acute", "Latin Letters")
	AddCode("Ņ", "&#325;", "\0145", "U+0145", "&Ncedil;", "Latin Capital Letter N with Cedilla", "Latin Letters")
	AddCode("ņ", "&#326;", "\0146", "U+0146", "&ncedil;", "Latin Small Letter N with Cedilla", "Latin Letters")
	AddCode("Ň", "&#327;", "\0147", "U+0147", "&Ncaron;", "Latin Capital Letter N with Caron", "Latin Letters")
	AddCode("ň", "&#328;", "\0148", "U+0148", "&ncaron;", "Latin Small Letter N with Caron", "Latin Letters")
	AddCode("ŉ", "&#329;", "\0149", "U+0149", "&napos;", "Latin Small Letter N Preceded By Apostrophe", "Latin Letters")
	AddCode("Ŋ", "&#330;", "\014A", "U+014A", "&ENG;", "Latin Capital Letter Eng", "Latin Letters")
	AddCode("ŋ", "&#331;", "\014B", "U+014B", "&eng;", "Latin Small Letter Eng", "Latin Letters")
	AddCode("Ō", "&#332;", "\014C", "U+014C", "&Omacr;", "Latin Capital Letter O with Macron", "Latin Letters")
	AddCode("ō", "&#333;", "\014D", "U+014D", "&omacr;", "Latin Small Letter O with Macron", "Latin Letters")
	AddCode("Ő", "&#336;", "\0150", "U+0150", "&Odblac;", "Latin Capital Letter O with Double Acute", "Latin Letters")
	AddCode("ő", "&#337;", "\0151", "U+0151", "&odblac;", "Latin Small Letter O with Double Acute", "Latin Letters")
	AddCode("Œ", "&#338;", "\0152", "U+0152", "&OElig;", "Latin Capital Ligature Oe", "Latin Letters")
	AddCode("œ", "&#339;", "\0153", "U+0153", "&oelig;", "Latin Small Ligature Oe", "Latin Letters")
	AddCode("Ŕ", "&#340;", "\0154", "U+0154", "&Racute;", "Latin Capital Letter R with Acute", "Latin Letters")
	AddCode("ŕ", "&#341;", "\0155", "U+0155", "&racute;", "Latin Small Letter R with Acute", "Latin Letters")
	AddCode("Ŗ", "&#342;", "\0156", "U+0156", "&Rcedil;", "Latin Capital Letter R with Cedilla", "Latin Letters")
	AddCode("ŗ", "&#343;", "\0157", "U+0157", "&rcedil;", "Latin Small Letter R with Cedilla", "Latin Letters")
	AddCode("Ř", "&#344;", "\0158", "U+0158", "&Rcaron;", "Latin Capital Letter R with Caron", "Latin Letters")
	AddCode("ř", "&#345;", "\0159", "U+0159", "&rcaron;", "Latin Small Letter R with Caron", "Latin Letters")
	AddCode("Ś", "&#346;", "\015A", "U+015A", "&Sacute;", "Latin Capital Letter S with Acute", "Latin Letters")
	AddCode("ś", "&#347;", "\015B", "U+015B", "&sacute;", "Latin Small Letter S with Acute", "Latin Letters")
	AddCode("Ŝ", "&#348;", "\015C", "U+015C", "&Scirc;", "Latin Capital Letter S with Circumflex", "Latin Letters")
	AddCode("ŝ", "&#349;", "\015D", "U+015D", "&scirc;", "Latin Small Letter S with Circumflex", "Latin Letters")
	AddCode("Ş", "&#350;", "\015E", "U+015E", "&Scedil;", "Latin Capital Letter S with Cedilla", "Latin Letters")
	AddCode("ş", "&#351;", "\015F", "U+015F", "&scedil;", "Latin Small Letter S with Cedilla", "Latin Letters")
	AddCode("Š", "&#352;", "\0160", "U+0160", "&Scaron;", "Latin Capital Letter S with Caron", "Latin Letters")
	AddCode("š", "&#353;", "\0161", "U+0161", "&scaron;", "Latin Small Letter S with Caron", "Latin Letters")
	AddCode("Ţ", "&#354;", "\0162", "U+0162", "&Tcedil;", "Latin Capital Letter T with Cedilla", "Latin Letters")
	AddCode("ţ", "&#355;", "\0163", "U+0163", "&tcedil;", "Latin Small Letter T with Cedilla", "Latin Letters")
	AddCode("Ť", "&#356;", "\0164", "U+0164", "&Tcaron;", "Latin Capital Letter T with Caron", "Latin Letters")
	AddCode("ť", "&#357;", "\0165", "U+0165", "&tcaron;", "Latin Small Letter T with Caron", "Latin Letters")
	AddCode("Ŧ", "&#358;", "\0166", "U+0166", "&Tstrok;", "Latin Capital Letter T with Stroke", "Latin Letters")
	AddCode("ŧ", "&#359;", "\0167", "U+0167", "&tstrok;", "Latin Small Letter T with Stroke", "Latin Letters")
	AddCode("Ũ", "&#360;", "\0168", "U+0168", "&Utilde;", "Latin Capital Letter U with Tilde", "Latin Letters")
	AddCode("ũ", "&#361;", "\0169", "U+0169", "&utilde;", "Latin Small Letter U with Tilde", "Latin Letters")
	AddCode("Ū", "&#362;", "\016A", "U+016A", "&Umacr;", "Latin Capital Letter U with Macron", "Latin Letters")
	AddCode("ū", "&#363;", "\016B", "U+016B", "&umacr;", "Latin Small Letter U with Macron", "Latin Letters")
	AddCode("Ŭ", "&#364;", "\016C", "U+016C", "&Ubreve;", "Latin Capital Letter U with Breve", "Latin Letters")
	AddCode("ŭ", "&#365;", "\016D", "U+016D", "&ubreve;", "Latin Small Letter U with Breve", "Latin Letters")
	AddCode("Ů", "&#366;", "\016E", "U+016E", "&Uring;", "Latin Capital Letter U with Ring Above", "Latin Letters")
	AddCode("ů", "&#367;", "\016F", "U+016F", "&uring;", "Latin Small Letter U with Ring Above", "Latin Letters")
	AddCode("Ű", "&#368;", "\0170", "U+0170", "&Udblac;", "Latin Capital Letter U with Double Acute", "Latin Letters")
	AddCode("ű", "&#369;", "\0171", "U+0171", "&udblac;", "Latin Small Letter U with Double Acute", "Latin Letters")
	AddCode("Ų", "&#370;", "\0172", "U+0172", "&Uogon;", "Latin Capital Letter U with Ogonek", "Latin Letters")
	AddCode("ų", "&#371;", "\0173", "U+0173", "&uogon;", "Latin Small Letter U with Ogonek", "Latin Letters")
	AddCode("Ŵ", "&#372;", "\0174", "U+0174", "&Wcirc;", "Latin Capital Letter W with Circumflex", "Latin Letters")
	AddCode("ŵ", "&#373;", "\0175", "U+0175", "&wcirc;", "Latin Small Letter W with Circumflex", "Latin Letters")
	AddCode("Ŷ", "&#374;", "\0176", "U+0176", "&Ycirc;", "Latin Capital Letter Y with Circumflex", "Latin Letters")
	AddCode("ŷ", "&#375;", "\0177", "U+0177", "&ycirc;", "Latin Small Letter Y with Circumflex", "Latin Letters")
	AddCode("Ÿ", "&#376;", "\0178", "U+0178", "&Yuml;", "Latin Capital Letter Y with Diaeresis", "Latin Letters")
	AddCode("Ź", "&#377;", "\0179", "U+0179", "&Zacute;", "Latin Capital Letter Z with Acute", "Latin Letters")
	AddCode("ź", "&#378;", "\017A", "U+017A", "&zacute;", "Latin Small Letter Z with Acute", "Latin Letters")
	AddCode("Ż", "&#379;", "\017B", "U+017B", "&Zdot;", "Latin Capital Letter Z with Dot Above", "Latin Letters")
	AddCode("ż", "&#380;", "\017C", "U+017C", "&zdot;", "Latin Small Letter Z with Dot Above", "Latin Letters")
	AddCode("Ž", "&#381;", "\017D", "U+017D", "&Zcaron;", "Latin Capital Letter Z with Caron", "Latin Letters")
	AddCode("ž", "&#382;", "\017E", "U+017E", "&zcaron;", "Latin Small Letter Z with Caron", "Latin Letters")
	AddCode("̑", "&#785;", "\0311", "U+0311", "&DownBreve;", "Combining Inverted Breve", "Latin Letters")
	AddCode("↺", "&#8634;", "\21BA", "U+21BA", "&olarr;", "Anticlockwise Open Circle Arrow", "Arrows")
	AddCode("↻", "&#8635;", "\21BB", "U+21BB", "&orarr;", "Clockwise Open Circle Arrow", "Arrows")
	AddCode("↼", "&#8636;", "\21BC", "U+21BC", "&lharu;", "Leftwards Harpoon with Barb Upwards", "Arrows")
	AddCode("↽", "&#8637;", "\21BD", "U+21BD", "&lhard;", "Leftwards Harpoon with Barb Downwards", "Arrows")
	AddCode("↾", "&#8638;", "\21BE", "U+21BE", "&uharr;", "Upwards Harpoon with Barb Rightwards", "Arrows")
	AddCode("↿", "&#8639;", "\21BF", "U+21BF", "&uharl;", "Upwards Harpoon with Barb Leftwards", "Arrows")
	AddCode("⇀", "&#8640;", "\21C0", "U+21C0", "&rharu;", "Rightwards Harpoon with Barb Upwards", "Arrows")
	AddCode("⇁", "&#8641;", "\21C1", "U+21C1", "&rhard;", "Rightwards Harpoon with Barb Downwards", "Arrows")
	AddCode("⇂", "&#8642;", "\21C2", "U+21C2", "&dharr;", "Downwards Harpoon with Barb Rightwards", "Arrows")
	AddCode("⇃", "&#8643;", "\21C3", "U+21C3", "&dharl;", "Downwards Harpoon with Barb Leftwards", "Arrows")
	AddCode("⇄", "&#8644;", "\21C4", "U+21C4", "&rlarr;", "Rightwards Arrow Over Leftwards Arrow", "Arrows")
	AddCode("⇅", "&#8645;", "\21C5", "U+21C5", "&udarr;", "Upwards Arrow Leftwards of Downwards Arrow", "Arrows")
	AddCode("⇆", "&#8646;", "\21C6", "U+21C6", "&lrarr;", "Leftwards Arrow Over Rightwards Arrow", "Arrows")
	AddCode("⇇", "&#8647;", "\21C7", "U+21C7", "&llarr;", "Leftwards Paired Arrows", "Arrows")
	AddCode("⇈", "&#8648;", "\21C8", "U+21C8", "&uuarr;", "Upwards Paired Arrows", "Arrows")
	AddCode("⇉", "&#8649;", "\21C9", "U+21C9", "&rrarr;", "Rightwards Paired Arrows", "Arrows")
	AddCode("⇊", "&#8650;", "\21CA", "U+21CA", "&ddarr;", "Downwards Paired Arrows", "Arrows")
	AddCode("⇋", "&#8651;", "\21CB", "U+21CB", "&lrhar;", "Leftwards Harpoon Over Rightwards Harpoon", "Arrows")
	AddCode("⇌", "&#8652;", "\21CC", "U+21CC", "&rlhar;", "Rightwards Harpoon Over Leftwards Harpoon", "Arrows")
	AddCode("⇍", "&#8653;", "\21CD", "U+21CD", "&nlArr;", "Leftwards Double Arrow with Stroke", "Arrows")
	AddCode("⇎", "&#8654;", "\21CE", "U+21CE", "&nhArr;", "Left Right Double Arrow with Stroke", "Arrows")
	AddCode("⇏", "&#8655;", "\21CF", "U+21CF", "&nrArr;", "Rightwards Double Arrow with Stroke", "Arrows")
	AddCode("⇐", "&#8656;", "\21D0", "U+21D0", "&lArr;", "Leftwards Double Arrow", "Arrows")
	AddCode("⇑", "&#8657;", "\21D1", "U+21D1", "&uArr;", "Upwards Double Arrow", "Arrows")
	AddCode("⇒", "&#8658;", "\21D2", "U+21D2", "&rArr;", "Rightwards Double Arrow", "Arrows")
	AddCode("⇓", "&#8659;", "\21D3", "U+21D3", "&dArr;", "Downwards Double Arrow", "Arrows")
	AddCode("⇔", "&#8660;", "\21D4", "U+21D4", "&hArr;", "Left Right Double Arrow", "Arrows")
	AddCode("⇕", "&#8661;", "\21D5", "U+21D5", "&vArr;", "Up Down Double Arrow", "Arrows")
	AddCode("⇖", "&#8662;", "\21D6", "U+21D6", "&nwArr;", "North West Double Arrow", "Arrows")
	AddCode("⇗", "&#8663;", "\21D7", "U+21D7", "&neArr;", "North East Double Arrow", "Arrows")
	AddCode("⇘", "&#8664;", "\21D8", "U+21D8", "&seArr;", "South East Double Arrow", "Arrows")
	AddCode("⇙", "&#8665;", "\21D9", "U+21D9", "&swArr;", "South West Double Arrow", "Arrows")
	AddCode("⇚", "&#8666;", "\21DA", "U+21DA", "&lAarr;", "Leftwards Triple Arrow", "Arrows")
	AddCode("⇛", "&#8667;", "\21DB", "U+21DB", "&rAarr;", "Rightwards Triple Arrow", "Arrows")
	AddCode("⇜", "&#8668;", "\21DC", "U+21DC", "&ziglarr;", "Leftwards Squiggle Arrow", "Arrows")
	AddCode("⇝", "&#8669;", "\21DD", "U+21DD", "&zigrarr;", "Rightwards Squiggle Arrow", "Arrows")
	AddCode("⇤", "&#8676;", "\21E4", "U+21E4", "&larrb;", "Leftwards Arrow To Bar", "Arrows")
	AddCode("⇥", "&#8677;", "\21E5", "U+21E5", "&rarrb;", "Rightwards Arrow To Bar", "Arrows")
	AddCode("⇵", "&#8693;", "\21F5", "U+21F5", "&duarr;", "Downwards Arrow Leftwards of Upwards Arrow", "Arrows")
	AddCode("⇿", "&#8703;", "\21FF", "U+21FF", "&hoarr;", "Left Right Open-Headed Arrow", "Arrows")
	AddCode("⇽", "&#8701;", "\21FD", "U+21FD", "&loarr;", "Leftwards Open-Headed Arrow", "Arrows")
	AddCode("⇾", "&#8702;", "\21FE", "U+21FE", "&roarr;", "Rightwards Open-Headed Arrow", "Arrows")
	AddCode("⟵", "&#10229;", "\27F5", "U+27F5", "&xlarr;", "Long Leftwards Arrow", "Arrows")
	AddCode("⟶", "&#10230;", "\27F6", "U+27F6", "&xrarr;", "Long Rightwards Arrow", "Arrows")
	AddCode("⟷", "&#10231;", "\27F7", "U+27F7", "&xharr;", "Long Left Right Arrow", "Arrows")
	AddCode("⟸", "&#10232;", "\27F8", "U+27F8", "&xlArr;", "Long Leftwards Double Arrow", "Arrows")
	AddCode("⟹", "&#10233;", "\27F9", "U+27F9", "&xrArr;", "Long Rightwards Double Arrow", "Arrows")
	AddCode("⟺", "&#10234;", "\27FA", "U+27FA", "&xhArr;", "Long Left Right Double Arrow", "Arrows")
	AddCode("⟿", "&#10239;", "\27FF", "U+27FF", "&dzigrarr;", "Long Rightwards Squiggle Arrow", "Arrows")
	AddCode("⟼", "&#10236;", "\27FC", "U+27FC", "&xmap;", "Long Rightwards Arrow from Bar", "Arrows")
	AddCode("⤂", "&#10498;", "\2902", "U+2902", "&nvlArr;", "Leftwards Double Arrow with Vertical Stroke", "Arrows")
	AddCode("⤃", "&#10499;", "\2903", "U+2903", "&nvrArr;", "Rightwards Double Arrow with Vertical Stroke", "Arrows")
	AddCode("⤄", "&#10500;", "\2904", "U+2904", "&nvHarr;", "Left Right Double Arrow with Vertical Stroke", "Arrows")
	AddCode("⤅", "&#10501;", "\2905", "U+2905", "&Map;", "Rightwards Two-Headed Arrow from Bar", "Arrows")
	AddCode("⤌", "&#10508;", "\290C", "U+290C", "&lbarr;", "Leftwards Double Dash Arrow", "Arrows")
	AddCode("⤍", "&#10509;", "\290D", "U+290D", "&rbarr;", "Rightwards Double Dash Arrow", "Arrows")
	AddCode("⤎", "&#10510;", "\290E", "U+290E", "&lBarr;", "Leftwards Triple Dash Arrow", "Arrows")
	AddCode("⤏", "&#10511;", "\290F", "U+290F", "&rBarr;", "Rightwards Triple Dash Arrow", "Arrows")
	AddCode("⤐", "&#10512;", "\2910", "U+2910", "&RBarr;", "Rightwards Two-Headed Triple Dash Arrow", "Arrows")
	AddCode("⤑", "&#10513;", "\2911", "U+2911", "&DDotrahd;", "Rightwards Arrow with Dotted Stem", "Arrows")
	AddCode("⤒", "&#10514;", "\2912", "U+2912", "&UpArrowBar;", "Upwards Arrow To Bar", "Arrows")
	AddCode("⤓", "&#10515;", "\2913", "U+2913", "&DownArrowBar;", "Downwards Arrow To Bar", "Arrows")
	AddCode("⤖", "&#10518;", "\2916", "U+2916", "&Rarrtl;", "Rightwards Two-Headed Arrow with Tail", "Arrows")
	AddCode("⤙", "&#10521;", "\2919", "U+2919", "&latail;", "Leftwards Arrow-Tail", "Arrows")
	AddCode("⤚", "&#10522;", "\291A", "U+291A", "&ratail;", "Rightwards Arrow-Tail", "Arrows")
	AddCode("⤛", "&#10523;", "\291B", "U+291B", "&lAtail;", "Leftwards Double Arrow-Tail", "Arrows")
	AddCode("⤜", "&#10524;", "\291C", "U+291C", "&rAtail;", "Rightwards Double Arrow-Tail", "Arrows")
	AddCode("⤝", "&#10525;", "\291D", "U+291D", "&larrfs;", "Leftwards Arrow To Black Diamond", "Arrows")
	AddCode("⤞", "&#10526;", "\291E", "U+291E", "&rarrfs;", "Rightwards Arrow To Black Diamond", "Arrows")
	AddCode("⤟", "&#10527;", "\291F", "U+291F", "&larrbfs;", "Leftwards Arrow from Bar To Black Diamond", "Arrows")
	AddCode("⤠", "&#10528;", "\2920", "U+2920", "&rarrbfs;", "Rightwards Arrow from Bar To Black Diamond", "Arrows")
	AddCode("⤣", "&#10531;", "\2923", "U+2923", "&nwarhk;", "North West Arrow with Hook", "Arrows")
	AddCode("⤤", "&#10532;", "\2924", "U+2924", "&nearhk;", "North East Arrow with Hook", "Arrows")
	AddCode("⤥", "&#10533;", "\2925", "U+2925", "&searhk;", "South East Arrow with Hook", "Arrows")
	AddCode("⤦", "&#10534;", "\2926", "U+2926", "&swarhk;", "South West Arrow with Hook", "Arrows")
	AddCode("⤧", "&#10535;", "\2927", "U+2927", "&nwnear;", "North West Arrow and North East Arrow", "Arrows")
	AddCode("⤨", "&#10536;", "\2928", "U+2928", "&nesear;", "North East Arrow and South East Arrow", "Arrows")
	AddCode("⤩", "&#10537;", "\2929", "U+2929", "&seswar;", "South East Arrow and South West Arrow", "Arrows")
	AddCode("⤪", "&#10538;", "\292A", "U+292A", "&swnwar;", "South West Arrow and North West Arrow", "Arrows")
	AddCode(" ", "&#10549;", "\2935", "U+2935", "&cudarrr;", "Right Arrow Curving Down", "Arrows")
	AddCode("⤶", "&#10550;", "\2936", "U+2936", "&ldca;", "Arrow Pointing Downwards Then Curving Leftwards", "Arrows")
	AddCode("⤷", "&#10551;", "\2937", "U+2937", "&rdca;", "Arrow Pointing Downwards Then Curving Rightwards", "Arrows")
	AddCode("⤸", "&#10552;", "\2938", "U+2938", "&cudarrl;", "Right-Side Arc Clockwise Arrow", "Arrows")
	AddCode("⤹", "&#10553;", "\2939", "U+2939", "&larrpl;", "Left-Side Arc Anticlockwise Arrow", "Arrows")
	AddCode("⤼", "&#10556;", "\293C", "U+293C", "&curarrm;", "Top Arc Clockwise Arrow with Minus", "Arrows")
	AddCode("⤽", "&#10557;", "\293D", "U+293D", "&cularrp;", "Top Arc Anticlockwise Arrow with Plus", "Arrows")
	AddCode("⥅", "&#10565;", "\2945", "U+2945", "&rarrpl;", "Rightwards Arrow with Plus Below", "Arrows")
	AddCode("⥈", "&#10568;", "\2948", "U+2948", "&harrcir;", "Left Right Arrow Through Small Circle", "Arrows")
	AddCode("⥉", "&#10569;", "\2949", "U+2949", "&Uarrocir;", "Upwards Two-Headed Arrow from Small Circle", "Arrows")
	AddCode("⥊", "&#10570;", "\294A", "U+294A", "&lurdshar;", "Left Barb Up Right Barb Down Harpoon", "Arrows")
	AddCode("⥋", "&#10571;", "\294B", "U+294B", "&ldrushar;", "Left Barb Down Right Barb Up Harpoon", "Arrows")
	AddCode("⥏", "&#10575;", "\294F", "U+294F", "&RightUpDownVector;", "Up Barb Right Down Barb Right Harpoon", "Arrows")
	AddCode("⥐", "&#10576;", "\2950", "U+2950", "&DownLeftRightVector;", "Left Barb Down Right Barb Down Harpoon", "Arrows")
	AddCode("⥑", "&#10577;", "\2951", "U+2951", "&LeftUpDownVector;", "Up Barb Left Down Barb Left Harpoon", "Arrows")
	AddCode("⥒", "&#10578;", "\2952", "U+2952", "&LeftVectorBar;", "Leftwards Harpoon with Barb Up To Bar", "Arrows")
	AddCode("⥓", "&#10579;", "\2953", "U+2953", "&RightVectorBar;", "Rightwards Harpoon with Barb Up To Bar", "Arrows")
	AddCode("⥔", "&#10580;", "\2954", "U+2954", "&RightUpVectorBar;", "Upwards Harpoon with Barb Right To Bar", "Arrows")
	AddCode("⥕", "&#10581;", "\2955", "U+2955", "&RightDownVectorBar;", "Downwards Harpoon with Barb Right To Bar", "Arrows")
	AddCode("⥖", "&#10582;", "\2956", "U+2956", "&DownLeftVectorBar;", "Leftwards Harpoon with Barb Down To Bar", "Arrows")
	AddCode("⥗", "&#10583;", "\2957", "U+2957", "&DownRightVectorBar;", "Rightwards Harpoon with Barb Down To Bar", "Arrows")
	AddCode("⥘", "&#10584;", "\2958", "U+2958", "&LeftUpVectorBar;", "Upwards Harpoon with Barb Left To Bar", "Arrows")
	AddCode("⥙", "&#10585;", "\2959", "U+2959", "&LeftDownVectorBar;", "Downwards Harpoon with Barb Left To Bar", "Arrows")
	AddCode("⥚", "&#10586;", "\295A", "U+295A", "&LeftTeeVector;", "Leftwards Harpoon with Barb Up from Bar", "Arrows")
	AddCode("⥛", "&#10587;", "\295B", "U+295B", "&RightTeeVector;", "Rightwards Harpoon with Barb Up from Bar", "Arrows")
	AddCode("⥜", "&#10588;", "\295C", "U+295C", "&RightUpTeeVector;", "Upwards Harpoon with Barb Right from Bar", "Arrows")
	AddCode("⥝", "&#10589;", "\295D", "U+295D", "&RightDownTeeVector;", "Downwards Harpoon with Barb Right from Bar", "Arrows")
	AddCode("⥞", "&#10590;", "\295E", "U+295E", "&DownLeftTeeVector;", "Leftwards Harpoon with Barb Down from Bar", "Arrows")
	AddCode("⥟", "&#10591;", "\295F", "U+295F", "&DownRightTeeVector;", "Rightwards Harpoon with Barb Down from Bar", "Arrows")
	AddCode("⥠", "&#10592;", "\2960", "U+2960", "&LeftUpTeeVector;", "Upwards Harpoon with Barb Left from Bar", "Arrows")
	AddCode("⥡", "&#10593;", "\2961", "U+2961", "&LeftDownTeeVector;", "Downwards Harpoon with Barb Left from Bar", "Arrows")
	AddCode("⥢", "&#10594;", "\2962", "U+2962", "&lHar;", "Leftwards Harpoon with Barb Up Above Leftwards Harpoon with Barb Down", "Arrows")
	AddCode("⥣", "&#10595;", "\2963", "U+2963", "&uHar;", "Upwards Harpoon with Barb Left Beside Upwards Harpoon with Barb Right", "Arrows")
	AddCode("⥤", "&#10596;", "\2964", "U+2964", "&rHar;", "Rightwards Harpoon with Barb Up Above Rightwards Harpoon with Barb Down", "Arrows")
	AddCode("⥥", "&#10597;", "\2965", "U+2965", "&dHar;", "Downwards Harpoon with Barb Left Beside Downwards Harpoon with Barb Right", "Arrows")
	AddCode("⥦", "&#10598;", "\2966", "U+2966", "&luruhar;", "Leftwards Harpoon with Barb Up Above Rightwards Harpoon with Barb Up", "Arrows")
	AddCode("⥧", "&#10599;", "\2967", "U+2967", "&ldrdhar;", "Leftwards Harpoon with Barb Down Above Rightwards Harpoon with Barb Down", "Arrows")
	AddCode("⥨", "&#10600;", "\2968", "U+2968", "&ruluhar;", "Rightwards Harpoon with Barb Up Above Leftwards Harpoon with Barb Up", "Arrows")
	AddCode("⥩", "&#10601;", "\2969", "U+2969", "&rdldhar;", "Rightwards Harpoon with Barb Down Above Leftwards Harpoon with Barb Down", "Arrows")
	AddCode("⥪", "&#10602;", "\296A", "U+296A", "&lharul;", "Leftwards Harpoon with Barb Up Above Long Dash", "Arrows")
	AddCode("⥫", "&#10603;", "\296B", "U+296B", "&llhard;", "Leftwards Harpoon with Barb Down Below Long Dash", "Arrows")
	AddCode("⥬", "&#10604;", "\296C", "U+296C", "&rharul;", "Rightwards Harpoon with Barb Up Above Long Dash", "Arrows")
	AddCode("⥭", "&#10605;", "\296D", "U+296D", "&lrhard;", "Rightwards Harpoon with Barb Down Below Long Dash", "Arrows")
	AddCode("⥮", "&#10606;", "\296E", "U+296E", "&udhar;", "Upwards Harpoon with Barb Left Beside Downwards Harpoon with Barb Right", "Arrows")
	AddCode("⥯", "&#10607;", "\296F", "U+296F", "&duhar;", "Downwards Harpoon with Barb Left Beside Upwards Harpoon with Barb Right", "Arrows")
	AddCode("⥰", "&#10608;", "\2970", "U+2970", "&RoundImplies;", "Right Double Arrow with Rounded Head", "Arrows")
	AddCode("⥱", "&#10609;", "\2971", "U+2971", "&erarr;", "Equals Sign Above Rightwards Arrow", "Arrows")
	AddCode("⥲", "&#10610;", "\2972", "U+2972", "&simrarr;", "Tilde Operator Above Rightwards Arrow", "Arrows")
	AddCode("⥳", "&#10611;", "\2973", "U+2973", "&larrsim;", "Leftwards Arrow Above Tilde Operator", "Arrows")
	AddCode("⥴", "&#10612;", "\2974", "U+2974", "&rarrsim;", "Rightwards Arrow Above Tilde Operator", "Arrows")
	AddCode("⥵", "&#10613;", "\2975", "U+2975", "&rarrap;", "Rightwards Arrow Above Almost Equal To", "Arrows")
	AddCode("⥶", "&#10614;", "\2976", "U+2976", "&ltlarr;", "Less-Than Above Leftwards Arrow", "Arrows")
	AddCode("⥸", "&#10616;", "\2978", "U+2978", "&gtrarr;", "Greater-Than Above Rightwards Arrow", "Arrows")
	AddCode("⥹", "&#10617;", "\2979", "U+2979", "&subrarr;", "Subset Above Rightwards Arrow", "Arrows")
	AddCode("⥻", "&#10619;", "\297B", "U+297B", "&suplarr;", "Superset Above Leftwards Arrow", "Arrows")
	AddCode("⥼", "&#10620;", "\297C", "U+297C", "&lfisht;", "Left Fish Tail", "Arrows")
	AddCode("⥽", "&#10621;", "\297D", "U+297D", "&rfisht;", "Right Fish Tail", "Arrows")
	AddCode("⥾", "&#10622;", "\297E", "U+297E", "&ufisht;", "Up Fish Tail", "Arrows")
	AddCode("⥿", "&#10623;", "\297F", "U+297F", "&dfisht;", "Down Fish Tail", "Arrows")

End Sub

Private Sub AddCode(symbol As String, htmlCode As String, CSScode As String, unicode As String, entity As String, name As String, group As String)

	Dim t1 As wmHtmlCode
	Dim i As Int = listHtmlCodes.Size
	Dim s As String

	t1.Initialize
	t1.id = i
	t1.symbol = symbol
	t1.htmlCode = htmlCode
	t1.CSScode = CSScode
	t1.unicode = unicode
	t1.entity = entity
	t1.name = name
	t1.group = group

	listHtmlCodes.Add(t1)

	mapEntity.Put(entity, t1.id)
	mapCSScode.Put(CSScode, t1.id)
	mapHtmlCode.Put(htmlCode, t1.id)
	mapName.Put(name, t1.id)
	mapSymbol.Put(symbol, t1.id)
	mapUnicode.Put(unicode, t1.id)

	If i > 0 Then
		s = entity.SubString2(1, entity.Length - 1) ' For entity "&quot;", this would be "quot"
		xmlEntities.Put(s, symbol)
		matcherPattern = matcherPattern & "|" & s
	End If

End Sub

' Get the wmHtmlCode type variable via the passed value (case-sensitive).
' If the value is not found, all string members of the variable are set to "".
Public Sub GetByEntity(entity As String) As wmHtmlCode

	Return GetOneCode(mapEntity, entity)

End Sub

' Get the wmHtmlCode type variable via the passed value (case-sensitive).
' If the value is not found, all string members of the variable are set to "".
Public Sub GetByCSScode(CSScode As String) As wmHtmlCode

	Return GetOneCode(mapCSScode, CSScode)

End Sub

' Get the wmHtmlCode type variable via the passed value (case-sensitive).
' If the value is not found, all string members of the variable are set to "".
Public Sub GetByHtmlCode(htmlCode As String) As wmHtmlCode

	Return GetOneCode(mapHtmlCode, htmlCode)

End Sub

' Get the wmHtmlCode type variable via the passed value (case-sensitive).
' If the value is not found, all string members of the variable are set to "".
Public Sub GetByName(name As String) As wmHtmlCode

	Return GetOneCode(mapName, name)

End Sub

' Get the wmHtmlCode type variable via the passed value (case-sensitive).
' If the value is not found, all string members of the variable are set to "".
Public Sub GetBySymbol(symbol As String) As wmHtmlCode

	Return GetOneCode(mapSymbol, symbol)

End Sub

' Get the wmHtmlCode type variable via the passed value (case-sensitive).
' If the value is not found, all string members of the variable are set to "".
Public Sub GetByUnicode(unicode As String) As wmHtmlCode

	Return GetOneCode(mapUnicode, unicode)

End Sub

' Get the symbol (character) via the passed value (case-sensitive).
' If the value is not found, the default value is returned.
Public Sub GetSymbolByEntity(entity As String, default As String) As String

	Dim t1 As wmHtmlCode =  GetByEntity(entity)
	Return IIf(t1.id = 0, default, t1.symbol)

End Sub

' Get the symbol (character) via the passed value (case-sensitive).
' If the value is not found, the default value is returned.
Public Sub GetSymbolByCSScode(CSScode As String, default As String) As String

	Dim t1 As wmHtmlCode =  GetByCSScode(CSScode)
	Return IIf(t1.id = 0, default, t1.symbol)

End Sub

' Get the symbol (character) via the passed value (case-sensitive).
' If the value is not found, the default value is returned.
Public Sub GetSymbolByHtmlCode(htmlCode As String, default As String) As String

	Dim t1 As wmHtmlCode =  GetByHtmlCode(htmlCode)
	Return IIf(t1.id = 0, default, t1.symbol)

End Sub

' Get the symbol (character) via the passed value (case-sensitive).
' If the value is not found, the default value is returned.
Public Sub GetSymbolByName(name As String, default As String) As String

	Dim t1 As wmHtmlCode =  GetByName(name)
	Return IIf(t1.id = 0, default, t1.symbol)

End Sub

' Get the symbol (character) via the passed value (case-sensitive).
' If the value is not found, the default value is returned.
Public Sub GetSymbolByUnicode(unicode As String, default As String) As String

	Dim t1 As wmHtmlCode =  GetByUnicode(unicode)
	Return IIf(t1.id = 0, default, t1.symbol)

End Sub

Private Sub GetOneCode(m As Map, s As String) As wmHtmlCode

	Dim i As Int = m.GetDefault(s, 0)
	Return listHtmlCodes.Get(i)

End Sub

' Decodes an html string and replaces the found encoded entities with their symbols (characters).
Public Sub DecodeHtml(encoded As String) As String

	' Code based on https://www.b4x.com/android/forum/threads/resolved-i-have-some-special-char-in-the-text-how-to-make-it-normal-html-decoder.58856/#post-370577

	Dim sb As StringBuilder
	sb.Initialize
	' Dim xmlEntities As Map = CreateMap("quot": QUOTE, "lt": "<", "gt": ">", "amp": "&") ' Original code
	' Dim m As Matcher = Regex.Matcher("&(#\d+|quot|lt|gt|amp);", encoded) ' Original code
	Dim m As Matcher = Regex.Matcher(matcherPattern, encoded) ' My code; matcherPattern is set by Initialize and AddCode
	Dim index As Int
	Do While m.Find
		sb.Append(encoded.SubString2(index, m.GetStart(0)))
		index = m.GetEnd(0)
		If xmlEntities.ContainsKey(m.Group(1)) Then
			sb.Append(xmlEntities.Get(m.Group(1)))
		Else
			Dim rawCodepoint As String = m.Group(1).SubString(1)
			If IsNumber(rawCodepoint) Then
				sb.Append(Chr(rawCodepoint))
			Else
				sb.Append(m.Match)
			End If
		End If
	Loop
	If index < encoded.Length Then sb.Append(encoded.SubString(index))
	Return sb.ToString

End Sub

' Remove all html tags from the given string and return the result.
Public Sub RemoveHtmlTags(encoded As String) As String

	' Code based on
	' - https://www.b4x.com/android/forum/threads/resolved-i-have-some-special-char-in-the-text-how-to-make-it-normal-html-decoder.58856/#post-370577
	' - http://www.b4x.com/android/forum/threads/remove-html-formatting-from-a-string.34816/

	Dim sb As StringBuilder
	sb.Initialize
	Dim m As Matcher = Regex.Matcher2("<[^>]*>", Regex.CASE_INSENSITIVE, encoded)
	Dim index As Int
	Do While m.Find
		sb.Append(encoded.SubString2(index, m.GetStart(0)))
		index = m.GetEnd(0)
	Loop
	If index < encoded.Length Then sb.Append(encoded.SubString(index))
	Return sb.ToString

End Sub